"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .add_knowledge_knowledge_base_id_add_postop import (
        AddKnowledgeKnowledgeBaseIDAddPostRequest,
        AddKnowledgeKnowledgeBaseIDAddPostRequestTypedDict,
    )
    from .addrequest import AddRequest, AddRequestTypedDict
    from .annotation import Annotation, AnnotationTypedDict
    from .annotationurlcitation import (
        AnnotationURLCitation,
        AnnotationURLCitationTypedDict,
    )
    from .app_api_public_v2_function_call_callfunctionrequest import (
        AppAPIPublicV2FunctionCallCallFunctionRequest,
        AppAPIPublicV2FunctionCallCallFunctionRequestTypedDict,
    )
    from .app_api_public_v2_function_call_callfunctionresponse import (
        AppAPIPublicV2FunctionCallCallFunctionResponse,
        AppAPIPublicV2FunctionCallCallFunctionResponseTypedDict,
        JSONPayload,
        JSONPayloadTypedDict,
    )
    from .app_api_public_v2_functions_callfunctionrequest import (
        AppAPIPublicV2FunctionsCallFunctionRequest,
        AppAPIPublicV2FunctionsCallFunctionRequestTypedDict,
    )
    from .app_api_public_v2_functions_callfunctionresponse import (
        AppAPIPublicV2FunctionsCallFunctionResponse,
        AppAPIPublicV2FunctionsCallFunctionResponseTypedDict,
    )
    from .audio import Audio, AudioTypedDict
    from .body_upload_file_knowledge_knowledge_base_id_upload_post import (
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPost,
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFile,
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFileTypedDict,
        BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostTypedDict,
    )
    from .call_function_functions_function_id_call_postop import (
        CallFunctionFunctionsFunctionIDCallPostRequest,
        CallFunctionFunctionsFunctionIDCallPostRequestTypedDict,
    )
    from .call_function_revision_functions_function_id_call_revision_id_postop import (
        CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequest,
        CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequestTypedDict,
    )
    from .chat_completions_openai_chat_completions_postop import (
        Payload,
        PayloadTypedDict,
    )
    from .chatcompletion import (
        ChatCompletion,
        ChatCompletionServiceTier,
        ChatCompletionTypedDict,
    )
    from .chatcompletionallowedtoolchoiceparam import (
        ChatCompletionAllowedToolChoiceParam,
        ChatCompletionAllowedToolChoiceParamTypedDict,
    )
    from .chatcompletionallowedtoolsparam import (
        ChatCompletionAllowedToolsParam,
        ChatCompletionAllowedToolsParamTypedDict,
        Mode,
    )
    from .chatcompletionassistantmessageparam import (
        ChatCompletionAssistantMessageParam,
        ChatCompletionAssistantMessageParamContent1,
        ChatCompletionAssistantMessageParamContent1TypedDict,
        ChatCompletionAssistantMessageParamContent2,
        ChatCompletionAssistantMessageParamContent2TypedDict,
        ChatCompletionAssistantMessageParamToolCall,
        ChatCompletionAssistantMessageParamToolCallTypedDict,
        ChatCompletionAssistantMessageParamTypedDict,
    )
    from .chatcompletionaudio import ChatCompletionAudio, ChatCompletionAudioTypedDict
    from .chatcompletionaudioparam import (
        ChatCompletionAudioParam,
        ChatCompletionAudioParamFormat,
        ChatCompletionAudioParamTypedDict,
        Voice,
        VoiceEnum,
        VoiceTypedDict,
    )
    from .chatcompletioncontentpartimageparam import (
        ChatCompletionContentPartImageParam,
        ChatCompletionContentPartImageParamTypedDict,
    )
    from .chatcompletioncontentpartinputaudioparam import (
        ChatCompletionContentPartInputAudioParam,
        ChatCompletionContentPartInputAudioParamTypedDict,
    )
    from .chatcompletioncontentpartrefusalparam import (
        ChatCompletionContentPartRefusalParam,
        ChatCompletionContentPartRefusalParamTypedDict,
    )
    from .chatcompletioncontentparttextparam import (
        ChatCompletionContentPartTextParam,
        ChatCompletionContentPartTextParamTypedDict,
    )
    from .chatcompletioncustomtoolparam import (
        ChatCompletionCustomToolParam,
        ChatCompletionCustomToolParamTypedDict,
    )
    from .chatcompletiondevelopermessageparam import (
        ChatCompletionDeveloperMessageParam,
        ChatCompletionDeveloperMessageParamContent,
        ChatCompletionDeveloperMessageParamContentTypedDict,
        ChatCompletionDeveloperMessageParamTypedDict,
    )
    from .chatcompletionfunctioncalloptionparam import (
        ChatCompletionFunctionCallOptionParam,
        ChatCompletionFunctionCallOptionParamTypedDict,
    )
    from .chatcompletionfunctionmessageparam import (
        ChatCompletionFunctionMessageParam,
        ChatCompletionFunctionMessageParamTypedDict,
    )
    from .chatcompletionfunctiontoolparam import (
        ChatCompletionFunctionToolParam,
        ChatCompletionFunctionToolParamTypedDict,
    )
    from .chatcompletionmessage import (
        ChatCompletionMessage,
        ChatCompletionMessageToolCall,
        ChatCompletionMessageToolCallTypedDict,
        ChatCompletionMessageTypedDict,
    )
    from .chatcompletionmessagecustomtoolcall import (
        ChatCompletionMessageCustomToolCall,
        ChatCompletionMessageCustomToolCallTypedDict,
    )
    from .chatcompletionmessagecustomtoolcallparam import (
        ChatCompletionMessageCustomToolCallParam,
        ChatCompletionMessageCustomToolCallParamTypedDict,
    )
    from .chatcompletionmessagefunctiontoolcall import (
        ChatCompletionMessageFunctionToolCall,
        ChatCompletionMessageFunctionToolCallTypedDict,
    )
    from .chatcompletionmessagefunctiontoolcallparam import (
        ChatCompletionMessageFunctionToolCallParam,
        ChatCompletionMessageFunctionToolCallParamTypedDict,
    )
    from .chatcompletionnamedtoolchoicecustomparam import (
        ChatCompletionNamedToolChoiceCustomParam,
        ChatCompletionNamedToolChoiceCustomParamTypedDict,
    )
    from .chatcompletionnamedtoolchoiceparam import (
        ChatCompletionNamedToolChoiceParam,
        ChatCompletionNamedToolChoiceParamTypedDict,
    )
    from .chatcompletionnonstreaming import (
        ChatCompletionNonStreaming,
        ChatCompletionNonStreamingFunctionCallEnum,
        ChatCompletionNonStreamingFunctionCallUnion,
        ChatCompletionNonStreamingFunctionCallUnionTypedDict,
        ChatCompletionNonStreamingMessage,
        ChatCompletionNonStreamingMessageTypedDict,
        ChatCompletionNonStreamingModality,
        ChatCompletionNonStreamingReasoningEffort,
        ChatCompletionNonStreamingResponseFormat,
        ChatCompletionNonStreamingResponseFormatTypedDict,
        ChatCompletionNonStreamingServiceTier,
        ChatCompletionNonStreamingStop,
        ChatCompletionNonStreamingStopTypedDict,
        ChatCompletionNonStreamingTool,
        ChatCompletionNonStreamingToolChoiceEnum,
        ChatCompletionNonStreamingToolChoiceUnion,
        ChatCompletionNonStreamingToolChoiceUnionTypedDict,
        ChatCompletionNonStreamingToolTypedDict,
        ChatCompletionNonStreamingTypedDict,
        ChatCompletionNonStreamingVerbosity,
    )
    from .chatcompletionpredictioncontentparam import (
        ChatCompletionPredictionContentParam,
        ChatCompletionPredictionContentParamContent,
        ChatCompletionPredictionContentParamContentTypedDict,
        ChatCompletionPredictionContentParamTypedDict,
    )
    from .chatcompletionstreaming import (
        ChatCompletionStreaming,
        ChatCompletionStreamingFunctionCallEnum,
        ChatCompletionStreamingFunctionCallUnion,
        ChatCompletionStreamingFunctionCallUnionTypedDict,
        ChatCompletionStreamingMessage,
        ChatCompletionStreamingMessageTypedDict,
        ChatCompletionStreamingModality,
        ChatCompletionStreamingReasoningEffort,
        ChatCompletionStreamingResponseFormat,
        ChatCompletionStreamingResponseFormatTypedDict,
        ChatCompletionStreamingServiceTier,
        ChatCompletionStreamingStop,
        ChatCompletionStreamingStopTypedDict,
        ChatCompletionStreamingTool,
        ChatCompletionStreamingToolChoiceEnum,
        ChatCompletionStreamingToolChoiceUnion,
        ChatCompletionStreamingToolChoiceUnionTypedDict,
        ChatCompletionStreamingToolTypedDict,
        ChatCompletionStreamingTypedDict,
        ChatCompletionStreamingVerbosity,
    )
    from .chatcompletionstreamoptionsparam import (
        ChatCompletionStreamOptionsParam,
        ChatCompletionStreamOptionsParamTypedDict,
    )
    from .chatcompletionsystemmessageparam import (
        ChatCompletionSystemMessageParam,
        ChatCompletionSystemMessageParamContent,
        ChatCompletionSystemMessageParamContentTypedDict,
        ChatCompletionSystemMessageParamTypedDict,
    )
    from .chatcompletiontokenlogprob import (
        ChatCompletionTokenLogprob,
        ChatCompletionTokenLogprobTypedDict,
    )
    from .chatcompletiontoolmessageparam import (
        ChatCompletionToolMessageParam,
        ChatCompletionToolMessageParamContent,
        ChatCompletionToolMessageParamContentTypedDict,
        ChatCompletionToolMessageParamTypedDict,
    )
    from .chatcompletionusermessageparam import (
        ChatCompletionUserMessageParam,
        ChatCompletionUserMessageParamContent1,
        ChatCompletionUserMessageParamContent1TypedDict,
        ChatCompletionUserMessageParamContent2,
        ChatCompletionUserMessageParamContent2TypedDict,
        ChatCompletionUserMessageParamTypedDict,
    )
    from .choice import Choice, ChoiceTypedDict, FinishReason
    from .choicelogprobs import ChoiceLogprobs, ChoiceLogprobsTypedDict
    from .completiontokensdetails import (
        CompletionTokensDetails,
        CompletionTokensDetailsTypedDict,
    )
    from .completionusage import CompletionUsage, CompletionUsageTypedDict
    from .create_dataset_entry_datasets_dataset_id_postop import (
        CreateDatasetEntryDatasetsDatasetIDPostRequest,
        CreateDatasetEntryDatasetsDatasetIDPostRequestTypedDict,
    )
    from .create_metric_spans_span_id_metrics_postop import (
        CreateMetricSpansSpanIDMetricsPostRequest,
        CreateMetricSpansSpanIDMetricsPostRequestTypedDict,
    )
    from .createdatasetentryrequest import (
        CreateDatasetEntryRequest,
        CreateDatasetEntryRequestTypedDict,
    )
    from .createdatasetentryresponse import (
        CreateDatasetEntryResponse,
        CreateDatasetEntryResponseTypedDict,
    )
    from .createembeddingrequest import (
        CreateEmbeddingRequest,
        CreateEmbeddingRequestTypedDict,
        Input,
        InputTypedDict,
    )
    from .createembeddingresponse import (
        CreateEmbeddingResponse,
        CreateEmbeddingResponseTypedDict,
    )
    from .createfunctionrequest import (
        CreateFunctionRequest,
        CreateFunctionRequestTypedDict,
    )
    from .createfunctionresponse import (
        CreateFunctionResponse,
        CreateFunctionResponseTypedDict,
    )
    from .createknowledgebaserequest import (
        CreateKnowledgeBaseRequest,
        CreateKnowledgeBaseRequestTypedDict,
    )
    from .createknowledgebaseresponse import (
        CreateKnowledgeBaseResponse,
        CreateKnowledgeBaseResponseTypedDict,
    )
    from .createmodelaliasrequest import (
        CreateModelAliasRequest,
        CreateModelAliasRequestTypedDict,
    )
    from .createmodelaliasresponse import (
        CreateModelAliasResponse,
        CreateModelAliasResponseTypedDict,
    )
    from .createspanmetricrequest import (
        CreateSpanMetricRequest,
        CreateSpanMetricRequestTypedDict,
    )
    from .createspanmetricresponse import (
        CreateSpanMetricResponse,
        CreateSpanMetricResponseTypedDict,
    )
    from .createspanrequest import CreateSpanRequest, CreateSpanRequestTypedDict
    from .createspanresponse import CreateSpanResponse, CreateSpanResponseTypedDict
    from .custom_output import CustomOutput, CustomOutputTypedDict
    from .customformatgrammar import CustomFormatGrammar, CustomFormatGrammarTypedDict
    from .customformatgrammargrammar import (
        CustomFormatGrammarGrammar,
        CustomFormatGrammarGrammarTypedDict,
        Syntax,
    )
    from .customformattext import CustomFormatText, CustomFormatTextTypedDict
    from .delete_custom_model_models_custom_model_id_deleteop import (
        DeleteCustomModelModelsCustomModelIDDeleteRequest,
        DeleteCustomModelModelsCustomModelIDDeleteRequestTypedDict,
    )
    from .delete_dataset_entry_datasets_dataset_id_entries_entry_id_deleteop import (
        DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequest,
        DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequestTypedDict,
    )
    from .delete_documents_knowledge_knowledge_base_id_query_deleteop import (
        DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequest,
        DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequestTypedDict,
    )
    from .delete_file_from_knowledge_base_knowledge_knowledge_base_id_files_file_id_deleteop import (
        DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequest,
        DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequestTypedDict,
    )
    from .delete_function_functions_function_id_deleteop import (
        DeleteFunctionFunctionsFunctionIDDeleteRequest,
        DeleteFunctionFunctionsFunctionIDDeleteRequestTypedDict,
    )
    from .delete_knowledge_base_knowledge_knowledge_base_id_deleteop import (
        DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequest,
        DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequestTypedDict,
    )
    from .delete_metric_spans_span_id_metrics_metric_id_deleteop import (
        DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequest,
        DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequestTypedDict,
    )
    from .delete_model_alias_models_aliases_alias_id_deleteop import (
        DeleteModelAliasModelsAliasesAliasIDDeleteRequest,
        DeleteModelAliasModelsAliasesAliasIDDeleteRequestTypedDict,
    )
    from .delete_span_spans_span_id_deleteop import (
        DeleteSpanSpansSpanIDDeleteRequest,
        DeleteSpanSpansSpanIDDeleteRequestTypedDict,
    )
    from .deleteknowledgebaserequest import (
        DeleteKnowledgeBaseRequest,
        DeleteKnowledgeBaseRequestTypedDict,
    )
    from .deleteknowledgebaseresponse import (
        DeleteKnowledgeBaseResponse,
        DeleteKnowledgeBaseResponseTypedDict,
    )
    from .example import Example, ExampleTypedDict
    from .examplein import ExampleIn, ExampleInTypedDict
    from .feedbackinfo import FeedbackInfo, FeedbackInfoTypedDict
    from .file import File, FileTypedDict
    from .filedownloadurlresponse import (
        FileDownloadURLResponse,
        FileDownloadURLResponseTypedDict,
    )
    from .filefile import FileFile, FileFileTypedDict
    from .filter_ import (
        Filter,
        FilterTypedDict,
        Value1,
        Value1TypedDict,
        Value2,
        Value2TypedDict,
    )
    from .function_output import FunctionOutput, FunctionOutputTypedDict
    from .function_stream_call_stream_postop import (
        Delta,
        DeltaTypedDict,
        FunctionStreamCallStreamPostResponse,
        FunctionStreamCallStreamPostResponseBody,
        FunctionStreamCallStreamPostResponseBodyTypedDict,
        FunctionStreamCallStreamPostResponseTypedDict,
        StreamingChunk,
        StreamingChunkTypedDict,
    )
    from .functioncall_input import FunctionCallInput, FunctionCallInputTypedDict
    from .functioncall_output import FunctionCallOutput, FunctionCallOutputTypedDict
    from .functioncallconfiguration_input import (
        FunctionCallConfigurationInput,
        FunctionCallConfigurationInputTypedDict,
    )
    from .functioncallconfiguration_output import (
        FunctionCallConfigurationOutput,
        FunctionCallConfigurationOutputTypedDict,
    )
    from .functiondefinition import FunctionDefinition, FunctionDefinitionTypedDict
    from .get_custom_model_by_name_models_custom_by_name_name_getop import (
        GetCustomModelByNameModelsCustomByNameNameGetRequest,
        GetCustomModelByNameModelsCustomByNameNameGetRequestTypedDict,
    )
    from .get_custom_model_models_custom_model_id_getop import (
        GetCustomModelModelsCustomModelIDGetRequest,
        GetCustomModelModelsCustomModelIDGetRequestTypedDict,
    )
    from .get_dataset_entry_datasets_dataset_id_entries_entry_id_getop import (
        GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequest,
        GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequestTypedDict,
    )
    from .get_file_download_url_knowledge_knowledge_base_id_files_file_id_download_url_getop import (
        GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequest,
        GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequestTypedDict,
    )
    from .get_function_by_name_functions_by_name_name_getop import (
        GetFunctionByNameFunctionsByNameNameGetRequest,
        GetFunctionByNameFunctionsByNameNameGetRequestTypedDict,
    )
    from .get_function_by_revision_functions_function_id_revisions_revision_id_getop import (
        GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequest,
        GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequestTypedDict,
    )
    from .get_function_functions_function_id_getop import (
        GetFunctionFunctionsFunctionIDGetRequest,
        GetFunctionFunctionsFunctionIDGetRequestTypedDict,
    )
    from .get_knowledge_base_by_name_knowledge_by_name_knowledge_base_name_getop import (
        GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequest,
        GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequestTypedDict,
    )
    from .get_knowledge_base_knowledge_knowledge_base_id_getop import (
        GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequest,
        GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequestTypedDict,
    )
    from .get_metric_spans_span_id_metrics_metric_id_getop import (
        GetMetricSpansSpanIDMetricsMetricIDGetRequest,
        GetMetricSpansSpanIDMetricsMetricIDGetRequestTypedDict,
    )
    from .get_model_alias_by_name_models_aliases_by_name_name_getop import (
        GetModelAliasByNameModelsAliasesByNameNameGetRequest,
        GetModelAliasByNameModelsAliasesByNameNameGetRequestTypedDict,
    )
    from .get_model_alias_models_aliases_alias_id_getop import (
        GetModelAliasModelsAliasesAliasIDGetRequest,
        GetModelAliasModelsAliasesAliasIDGetRequestTypedDict,
    )
    from .get_span_spans_span_id_getop import (
        GetSpanSpansSpanIDGetRequest,
        GetSpanSpansSpanIDGetRequestTypedDict,
    )
    from .get_trace_traces_trace_id_getop import (
        GetTraceTracesTraceIDGetRequest,
        GetTraceTracesTraceIDGetRequestTypedDict,
    )
    from .get_upload_url_knowledge_knowledge_base_id_upload_url_getop import (
        GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequest,
        GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequestTypedDict,
    )
    from .getcustommodelresponse import (
        GetCustomModelResponse,
        GetCustomModelResponseTypedDict,
    )
    from .getdatasetentriesresponse import (
        GetDatasetEntriesResponse,
        GetDatasetEntriesResponseTypedDict,
    )
    from .getdatasetentryresponse import (
        GetDatasetEntryResponse,
        GetDatasetEntryResponseTypedDict,
    )
    from .getfunctionresponse import GetFunctionResponse, GetFunctionResponseTypedDict
    from .getknowledgebaseresponse import (
        GetKnowledgeBaseResponse,
        GetKnowledgeBaseResponseTypedDict,
    )
    from .getmodelaliasresponse import (
        GetModelAliasResponse,
        GetModelAliasResponseTypedDict,
    )
    from .getspanmetricresponse import (
        GetSpanMetricResponse,
        GetSpanMetricResponseTypedDict,
    )
    from .getspanresponse import GetSpanResponse, GetSpanResponseTypedDict
    from .gettraceresponse import GetTraceResponse, GetTraceResponseTypedDict
    from .getuploadurlresponse import (
        GetUploadURLResponse,
        GetUploadURLResponseTypedDict,
    )
    from .getusageresultitem import GetUsageResultItem, GetUsageResultItemTypedDict
    from .granularity import Granularity
    from .imageurl import Detail, ImageURL, ImageURLTypedDict
    from .inputaudio import InputAudio, InputAudioFormat, InputAudioTypedDict
    from .jsonschema import JSONSchema, JSONSchemaTypedDict
    from .list_custom_models_models_custom_getop import (
        ListCustomModelsModelsCustomGetRequest,
        ListCustomModelsModelsCustomGetRequestTypedDict,
    )
    from .list_dataset_entries_datasets_dataset_id_entries_getop import (
        ListDatasetEntriesDatasetsDatasetIDEntriesGetRequest,
        ListDatasetEntriesDatasetsDatasetIDEntriesGetRequestTypedDict,
    )
    from .list_files_knowledge_knowledge_base_id_files_getop import (
        ListFilesKnowledgeKnowledgeBaseIDFilesGetRequest,
        ListFilesKnowledgeKnowledgeBaseIDFilesGetRequestTypedDict,
    )
    from .list_function_revisions_functions_function_id_revisions_getop import (
        ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequest,
        ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequestTypedDict,
    )
    from .list_functions_functions_getop import (
        ListFunctionsFunctionsGetRequest,
        ListFunctionsFunctionsGetRequestTypedDict,
    )
    from .list_knowledge_bases_knowledge_getop import (
        ListKnowledgeBasesKnowledgeGetRequest,
        ListKnowledgeBasesKnowledgeGetRequestTypedDict,
    )
    from .list_metrics_spans_span_id_metrics_getop import (
        ListMetricsSpansSpanIDMetricsGetRequest,
        ListMetricsSpansSpanIDMetricsGetRequestTypedDict,
    )
    from .list_model_aliases_models_aliases_getop import (
        ListModelAliasesModelsAliasesGetRequest,
        ListModelAliasesModelsAliasesGetRequestTypedDict,
    )
    from .list_models_models_getop import (
        ListModelsModelsGetRequest,
        ListModelsModelsGetRequestTypedDict,
    )
    from .list_traces_traces_getop import (
        ListTracesTracesGetRequest,
        ListTracesTracesGetRequestTypedDict,
    )
    from .listcustommodelsresponseitem import (
        ListCustomModelsResponseItem,
        ListCustomModelsResponseItemTypedDict,
    )
    from .listfilesresponse import ListFilesResponse, ListFilesResponseTypedDict
    from .listfunctionrevisionresponse import (
        ListFunctionRevisionResponse,
        ListFunctionRevisionResponseTypedDict,
    )
    from .listfunctionsresponseitem import (
        ListFunctionsResponseItem,
        ListFunctionsResponseItemTypedDict,
    )
    from .listknowledgebasesresponse import (
        ListKnowledgeBasesResponse,
        ListKnowledgeBasesResponseTypedDict,
    )
    from .listlanguagemodelsresponse import (
        ListLanguageModelsResponse,
        ListLanguageModelsResponseTypedDict,
    )
    from .listmodelaliasesresponseitem import (
        ListModelAliasesResponseItem,
        ListModelAliasesResponseItemTypedDict,
    )
    from .listrerankmodelsresponse import (
        ListRerankModelsResponse,
        ListRerankModelsResponseTypedDict,
    )
    from .listspanmetricsresponse import (
        ListSpanMetricsResponse,
        ListSpanMetricsResponseTypedDict,
    )
    from .listtracesresponse import ListTracesResponse, ListTracesResponseTypedDict
    from .meta import Meta, MetaTypedDict
    from .model import Model, ModelTypedDict
    from .op import Op
    from .openai_types_chat_chat_completion_custom_tool_param_custom import (
        Format,
        FormatTypedDict,
        OpenaiTypesChatChatCompletionCustomToolParamCustom,
        OpenaiTypesChatChatCompletionCustomToolParamCustomTypedDict,
    )
    from .openai_types_chat_chat_completion_message_custom_tool_call_param_custom import (
        OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustom,
        OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustomTypedDict,
    )
    from .openai_types_chat_chat_completion_message_function_tool_call_param_function import (
        OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunction,
        OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunctionTypedDict,
    )
    from .openai_types_chat_chat_completion_named_tool_choice_custom_param_custom import (
        OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustom,
        OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustomTypedDict,
    )
    from .openai_types_chat_chat_completion_named_tool_choice_param_function import (
        OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction,
        OpenaiTypesChatChatCompletionNamedToolChoiceParamFunctionTypedDict,
    )
    from .openai_types_chat_completion_create_params_function import (
        OpenaiTypesChatCompletionCreateParamsFunction,
        OpenaiTypesChatCompletionCreateParamsFunctionTypedDict,
    )
    from .paginatedresponse_getdatasetentriesresponse_ import (
        PaginatedResponseGetDatasetEntriesResponse,
        PaginatedResponseGetDatasetEntriesResponseTypedDict,
    )
    from .paginatedresponse_listcustommodelsresponseitem_ import (
        PaginatedResponseListCustomModelsResponseItem,
        PaginatedResponseListCustomModelsResponseItemTypedDict,
    )
    from .paginatedresponse_listfilesresponse_ import (
        PaginatedResponseListFilesResponse,
        PaginatedResponseListFilesResponseTypedDict,
    )
    from .paginatedresponse_listfunctionrevisionresponse_ import (
        PaginatedResponseListFunctionRevisionResponse,
        PaginatedResponseListFunctionRevisionResponseTypedDict,
    )
    from .paginatedresponse_listfunctionsresponseitem_ import (
        PaginatedResponseListFunctionsResponseItem,
        PaginatedResponseListFunctionsResponseItemTypedDict,
    )
    from .paginatedresponse_listknowledgebasesresponse_ import (
        PaginatedResponseListKnowledgeBasesResponse,
        PaginatedResponseListKnowledgeBasesResponseTypedDict,
    )
    from .paginatedresponse_listlanguagemodelsresponse_ import (
        PaginatedResponseListLanguageModelsResponse,
        PaginatedResponseListLanguageModelsResponseTypedDict,
    )
    from .paginatedresponse_listmodelaliasesresponseitem_ import (
        PaginatedResponseListModelAliasesResponseItem,
        PaginatedResponseListModelAliasesResponseItemTypedDict,
    )
    from .paginatedresponse_listrerankmodelsresponse_ import (
        PaginatedResponseListRerankModelsResponse,
        PaginatedResponseListRerankModelsResponseTypedDict,
    )
    from .paginatedresponse_listspanmetricsresponse_ import (
        PaginatedResponseListSpanMetricsResponse,
        PaginatedResponseListSpanMetricsResponseTypedDict,
    )
    from .paginatedresponse_listtracesresponse_ import (
        PaginatedResponseListTracesResponse,
        PaginatedResponseListTracesResponseTypedDict,
    )
    from .prompttokensdetails import PromptTokensDetails, PromptTokensDetailsTypedDict
    from .query_dataset_entries_datasets_dataset_id_entries_query_postop import (
        QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequest,
        QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequestTypedDict,
    )
    from .query_knowledge_base_knowledge_knowledge_base_id_query_postop import (
        QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequest,
        QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequestTypedDict,
    )
    from .querydatasetentriesresponse import (
        QueryDatasetEntriesResponse,
        QueryDatasetEntriesResponseTypedDict,
    )
    from .queryknowledgebaserequest import (
        QueryKnowledgeBaseRequest,
        QueryKnowledgeBaseRequestTypedDict,
    )
    from .queryknowledgebaseresponse import (
        QueryKnowledgeBaseResponse,
        QueryKnowledgeBaseResponseTypedDict,
    )
    from .register_file_upload_knowledge_knowledge_base_id_register_file_postop import (
        RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequest,
        RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequestTypedDict,
    )
    from .registercustommodelrequest import (
        RegisterCustomModelRequest,
        RegisterCustomModelRequestTypedDict,
    )
    from .registercustommodelresponse import (
        RegisterCustomModelResponse,
        RegisterCustomModelResponseTypedDict,
    )
    from .registerfileuploadrequest import (
        RegisterFileUploadRequest,
        RegisterFileUploadRequestTypedDict,
    )
    from .registerfileuploadresponse import (
        RegisterFileUploadResponse,
        RegisterFileUploadResponseTypedDict,
    )
    from .rerankcost import RerankCost, RerankCostTypedDict
    from .rerankdocument import RerankDocument, RerankDocumentTypedDict
    from .rerankrequestmodel import RerankRequestModel, RerankRequestModelTypedDict
    from .rerankresponsemodel import RerankResponseModel, RerankResponseModelTypedDict
    from .rerankresult import RerankResult, RerankResultTypedDict
    from .responseformatjsonobject import (
        ResponseFormatJSONObject,
        ResponseFormatJSONObjectTypedDict,
    )
    from .responseformatjsonschema import (
        ResponseFormatJSONSchema,
        ResponseFormatJSONSchemaTypedDict,
    )
    from .responseformattext import ResponseFormatText, ResponseFormatTextTypedDict
    from .save_to_dataset_spans_span_id_save_examples_postop import (
        SaveToDatasetSpansSpanIDSaveExamplesPostRequest,
        SaveToDatasetSpansSpanIDSaveExamplesPostRequestTypedDict,
    )
    from .savetodatasetresponse import (
        SaveToDatasetResponse,
        SaveToDatasetResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .spandata import SpanData, SpanDataTypedDict
    from .spanmetricdata import SpanMetricData, SpanMetricDataTypedDict
    from .spanschema import SpanSchema, SpanSchemaTypedDict
    from .stream_function_functions_function_id_call_stream_postop import (
        StreamFunctionFunctionsFunctionIDCallStreamPostData,
        StreamFunctionFunctionsFunctionIDCallStreamPostDataTypedDict,
        StreamFunctionFunctionsFunctionIDCallStreamPostRequest,
        StreamFunctionFunctionsFunctionIDCallStreamPostRequestTypedDict,
        StreamFunctionFunctionsFunctionIDCallStreamPostResponse,
        StreamFunctionFunctionsFunctionIDCallStreamPostResponseBody,
        StreamFunctionFunctionsFunctionIDCallStreamPostResponseBodyTypedDict,
        StreamFunctionFunctionsFunctionIDCallStreamPostResponseTypedDict,
    )
    from .stream_function_revision_functions_function_id_call_stream_revision_id_postop import (
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostData,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostDataTypedDict,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequest,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequestTypedDict,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponse,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBody,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBodyTypedDict,
        StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseTypedDict,
    )
    from .submit_span_feedback_spans_span_id_feedback_postop import (
        SubmitSpanFeedbackSpansSpanIDFeedbackPostRequest,
        SubmitSpanFeedbackSpansSpanIDFeedbackPostRequestTypedDict,
    )
    from .submitfeedbackrequest import (
        SubmitFeedbackRequest,
        SubmitFeedbackRequestTypedDict,
    )
    from .submitfeedbackresponse import (
        SubmitFeedbackResponse,
        SubmitFeedbackResponseTypedDict,
    )
    from .textprocessingconfiguration import (
        TextProcessingConfiguration,
        TextProcessingConfigurationTypedDict,
    )
    from .tmodel import TModel, TModel1, TModel1TypedDict, TModelTypedDict
    from .toplogprob import TopLogprob, TopLogprobTypedDict
    from .update_custom_model_models_custom_model_id_patchop import (
        UpdateCustomModelModelsCustomModelIDPatchRequest,
        UpdateCustomModelModelsCustomModelIDPatchRequestTypedDict,
    )
    from .update_dataset_entry_datasets_dataset_id_entries_entry_id_patchop import (
        UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequest,
        UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequestTypedDict,
    )
    from .update_function_functions_function_id_patchop import (
        UpdateFunctionFunctionsFunctionIDPatchRequest,
        UpdateFunctionFunctionsFunctionIDPatchRequestTypedDict,
    )
    from .update_metric_spans_span_id_metrics_metric_id_patchop import (
        UpdateMetricSpansSpanIDMetricsMetricIDPatchRequest,
        UpdateMetricSpansSpanIDMetricsMetricIDPatchRequestTypedDict,
    )
    from .update_model_alias_models_aliases_alias_id_patchop import (
        UpdateModelAliasModelsAliasesAliasIDPatchRequest,
        UpdateModelAliasModelsAliasesAliasIDPatchRequestTypedDict,
    )
    from .update_span_spans_span_id_patchop import (
        UpdateSpanSpansSpanIDPatchRequest,
        UpdateSpanSpansSpanIDPatchRequestTypedDict,
    )
    from .updatecustommodelrequest import (
        UpdateCustomModelRequest,
        UpdateCustomModelRequestTypedDict,
    )
    from .updatecustommodelresponse import (
        UpdateCustomModelResponse,
        UpdateCustomModelResponseTypedDict,
    )
    from .updatedatasetentryrequest import (
        UpdateDatasetEntryRequest,
        UpdateDatasetEntryRequestTypedDict,
    )
    from .updatedatasetentryresponse import (
        UpdateDatasetEntryResponse,
        UpdateDatasetEntryResponseTypedDict,
    )
    from .updatefunctionrequest import (
        UpdateFunctionRequest,
        UpdateFunctionRequestTypedDict,
    )
    from .updatefunctionresponse import (
        UpdateFunctionResponse,
        UpdateFunctionResponseTypedDict,
    )
    from .updatemodelaliasrequest import (
        UpdateModelAliasRequest,
        UpdateModelAliasRequestTypedDict,
    )
    from .updatemodelaliasresponse import (
        UpdateModelAliasResponse,
        UpdateModelAliasResponseTypedDict,
    )
    from .updatespanmetricrequest import (
        UpdateSpanMetricRequest,
        UpdateSpanMetricRequestTypedDict,
    )
    from .updatespanmetricresponse import (
        UpdateSpanMetricResponse,
        UpdateSpanMetricResponseTypedDict,
    )
    from .updatespanrequest import UpdateSpanRequest, UpdateSpanRequestTypedDict
    from .updatespanresponse import UpdateSpanResponse, UpdateSpanResponseTypedDict
    from .upload_file_knowledge_knowledge_base_id_upload_postop import (
        UploadFileKnowledgeKnowledgeBaseIDUploadPostRequest,
        UploadFileKnowledgeKnowledgeBaseIDUploadPostRequestTypedDict,
    )
    from .uploadfileresponse import UploadFileResponse, UploadFileResponseTypedDict
    from .usage_analytics_usage_getop import (
        UsageAnalyticsUsageGetRequest,
        UsageAnalyticsUsageGetRequestTypedDict,
    )
    from .websearchoptions import (
        SearchContextSize,
        WebSearchOptions,
        WebSearchOptionsTypedDict,
    )
    from .websearchoptionsuserlocation import (
        WebSearchOptionsUserLocation,
        WebSearchOptionsUserLocationTypedDict,
    )
    from .websearchoptionsuserlocationapproximate import (
        WebSearchOptionsUserLocationApproximate,
        WebSearchOptionsUserLocationApproximateTypedDict,
    )

__all__ = [
    "AddKnowledgeKnowledgeBaseIDAddPostRequest",
    "AddKnowledgeKnowledgeBaseIDAddPostRequestTypedDict",
    "AddRequest",
    "AddRequestTypedDict",
    "Annotation",
    "AnnotationTypedDict",
    "AnnotationURLCitation",
    "AnnotationURLCitationTypedDict",
    "AppAPIPublicV2FunctionCallCallFunctionRequest",
    "AppAPIPublicV2FunctionCallCallFunctionRequestTypedDict",
    "AppAPIPublicV2FunctionCallCallFunctionResponse",
    "AppAPIPublicV2FunctionCallCallFunctionResponseTypedDict",
    "AppAPIPublicV2FunctionsCallFunctionRequest",
    "AppAPIPublicV2FunctionsCallFunctionRequestTypedDict",
    "AppAPIPublicV2FunctionsCallFunctionResponse",
    "AppAPIPublicV2FunctionsCallFunctionResponseTypedDict",
    "Audio",
    "AudioTypedDict",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPost",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFile",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFileTypedDict",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostTypedDict",
    "CallFunctionFunctionsFunctionIDCallPostRequest",
    "CallFunctionFunctionsFunctionIDCallPostRequestTypedDict",
    "CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequest",
    "CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequestTypedDict",
    "ChatCompletion",
    "ChatCompletionAllowedToolChoiceParam",
    "ChatCompletionAllowedToolChoiceParamTypedDict",
    "ChatCompletionAllowedToolsParam",
    "ChatCompletionAllowedToolsParamTypedDict",
    "ChatCompletionAssistantMessageParam",
    "ChatCompletionAssistantMessageParamContent1",
    "ChatCompletionAssistantMessageParamContent1TypedDict",
    "ChatCompletionAssistantMessageParamContent2",
    "ChatCompletionAssistantMessageParamContent2TypedDict",
    "ChatCompletionAssistantMessageParamToolCall",
    "ChatCompletionAssistantMessageParamToolCallTypedDict",
    "ChatCompletionAssistantMessageParamTypedDict",
    "ChatCompletionAudio",
    "ChatCompletionAudioParam",
    "ChatCompletionAudioParamFormat",
    "ChatCompletionAudioParamTypedDict",
    "ChatCompletionAudioTypedDict",
    "ChatCompletionContentPartImageParam",
    "ChatCompletionContentPartImageParamTypedDict",
    "ChatCompletionContentPartInputAudioParam",
    "ChatCompletionContentPartInputAudioParamTypedDict",
    "ChatCompletionContentPartRefusalParam",
    "ChatCompletionContentPartRefusalParamTypedDict",
    "ChatCompletionContentPartTextParam",
    "ChatCompletionContentPartTextParamTypedDict",
    "ChatCompletionCustomToolParam",
    "ChatCompletionCustomToolParamTypedDict",
    "ChatCompletionDeveloperMessageParam",
    "ChatCompletionDeveloperMessageParamContent",
    "ChatCompletionDeveloperMessageParamContentTypedDict",
    "ChatCompletionDeveloperMessageParamTypedDict",
    "ChatCompletionFunctionCallOptionParam",
    "ChatCompletionFunctionCallOptionParamTypedDict",
    "ChatCompletionFunctionMessageParam",
    "ChatCompletionFunctionMessageParamTypedDict",
    "ChatCompletionFunctionToolParam",
    "ChatCompletionFunctionToolParamTypedDict",
    "ChatCompletionMessage",
    "ChatCompletionMessageCustomToolCall",
    "ChatCompletionMessageCustomToolCallParam",
    "ChatCompletionMessageCustomToolCallParamTypedDict",
    "ChatCompletionMessageCustomToolCallTypedDict",
    "ChatCompletionMessageFunctionToolCall",
    "ChatCompletionMessageFunctionToolCallParam",
    "ChatCompletionMessageFunctionToolCallParamTypedDict",
    "ChatCompletionMessageFunctionToolCallTypedDict",
    "ChatCompletionMessageToolCall",
    "ChatCompletionMessageToolCallTypedDict",
    "ChatCompletionMessageTypedDict",
    "ChatCompletionNamedToolChoiceCustomParam",
    "ChatCompletionNamedToolChoiceCustomParamTypedDict",
    "ChatCompletionNamedToolChoiceParam",
    "ChatCompletionNamedToolChoiceParamTypedDict",
    "ChatCompletionNonStreaming",
    "ChatCompletionNonStreamingFunctionCallEnum",
    "ChatCompletionNonStreamingFunctionCallUnion",
    "ChatCompletionNonStreamingFunctionCallUnionTypedDict",
    "ChatCompletionNonStreamingMessage",
    "ChatCompletionNonStreamingMessageTypedDict",
    "ChatCompletionNonStreamingModality",
    "ChatCompletionNonStreamingReasoningEffort",
    "ChatCompletionNonStreamingResponseFormat",
    "ChatCompletionNonStreamingResponseFormatTypedDict",
    "ChatCompletionNonStreamingServiceTier",
    "ChatCompletionNonStreamingStop",
    "ChatCompletionNonStreamingStopTypedDict",
    "ChatCompletionNonStreamingTool",
    "ChatCompletionNonStreamingToolChoiceEnum",
    "ChatCompletionNonStreamingToolChoiceUnion",
    "ChatCompletionNonStreamingToolChoiceUnionTypedDict",
    "ChatCompletionNonStreamingToolTypedDict",
    "ChatCompletionNonStreamingTypedDict",
    "ChatCompletionNonStreamingVerbosity",
    "ChatCompletionPredictionContentParam",
    "ChatCompletionPredictionContentParamContent",
    "ChatCompletionPredictionContentParamContentTypedDict",
    "ChatCompletionPredictionContentParamTypedDict",
    "ChatCompletionServiceTier",
    "ChatCompletionStreamOptionsParam",
    "ChatCompletionStreamOptionsParamTypedDict",
    "ChatCompletionStreaming",
    "ChatCompletionStreamingFunctionCallEnum",
    "ChatCompletionStreamingFunctionCallUnion",
    "ChatCompletionStreamingFunctionCallUnionTypedDict",
    "ChatCompletionStreamingMessage",
    "ChatCompletionStreamingMessageTypedDict",
    "ChatCompletionStreamingModality",
    "ChatCompletionStreamingReasoningEffort",
    "ChatCompletionStreamingResponseFormat",
    "ChatCompletionStreamingResponseFormatTypedDict",
    "ChatCompletionStreamingServiceTier",
    "ChatCompletionStreamingStop",
    "ChatCompletionStreamingStopTypedDict",
    "ChatCompletionStreamingTool",
    "ChatCompletionStreamingToolChoiceEnum",
    "ChatCompletionStreamingToolChoiceUnion",
    "ChatCompletionStreamingToolChoiceUnionTypedDict",
    "ChatCompletionStreamingToolTypedDict",
    "ChatCompletionStreamingTypedDict",
    "ChatCompletionStreamingVerbosity",
    "ChatCompletionSystemMessageParam",
    "ChatCompletionSystemMessageParamContent",
    "ChatCompletionSystemMessageParamContentTypedDict",
    "ChatCompletionSystemMessageParamTypedDict",
    "ChatCompletionTokenLogprob",
    "ChatCompletionTokenLogprobTypedDict",
    "ChatCompletionToolMessageParam",
    "ChatCompletionToolMessageParamContent",
    "ChatCompletionToolMessageParamContentTypedDict",
    "ChatCompletionToolMessageParamTypedDict",
    "ChatCompletionTypedDict",
    "ChatCompletionUserMessageParam",
    "ChatCompletionUserMessageParamContent1",
    "ChatCompletionUserMessageParamContent1TypedDict",
    "ChatCompletionUserMessageParamContent2",
    "ChatCompletionUserMessageParamContent2TypedDict",
    "ChatCompletionUserMessageParamTypedDict",
    "Choice",
    "ChoiceLogprobs",
    "ChoiceLogprobsTypedDict",
    "ChoiceTypedDict",
    "CompletionTokensDetails",
    "CompletionTokensDetailsTypedDict",
    "CompletionUsage",
    "CompletionUsageTypedDict",
    "CreateDatasetEntryDatasetsDatasetIDPostRequest",
    "CreateDatasetEntryDatasetsDatasetIDPostRequestTypedDict",
    "CreateDatasetEntryRequest",
    "CreateDatasetEntryRequestTypedDict",
    "CreateDatasetEntryResponse",
    "CreateDatasetEntryResponseTypedDict",
    "CreateEmbeddingRequest",
    "CreateEmbeddingRequestTypedDict",
    "CreateEmbeddingResponse",
    "CreateEmbeddingResponseTypedDict",
    "CreateFunctionRequest",
    "CreateFunctionRequestTypedDict",
    "CreateFunctionResponse",
    "CreateFunctionResponseTypedDict",
    "CreateKnowledgeBaseRequest",
    "CreateKnowledgeBaseRequestTypedDict",
    "CreateKnowledgeBaseResponse",
    "CreateKnowledgeBaseResponseTypedDict",
    "CreateMetricSpansSpanIDMetricsPostRequest",
    "CreateMetricSpansSpanIDMetricsPostRequestTypedDict",
    "CreateModelAliasRequest",
    "CreateModelAliasRequestTypedDict",
    "CreateModelAliasResponse",
    "CreateModelAliasResponseTypedDict",
    "CreateSpanMetricRequest",
    "CreateSpanMetricRequestTypedDict",
    "CreateSpanMetricResponse",
    "CreateSpanMetricResponseTypedDict",
    "CreateSpanRequest",
    "CreateSpanRequestTypedDict",
    "CreateSpanResponse",
    "CreateSpanResponseTypedDict",
    "CustomFormatGrammar",
    "CustomFormatGrammarGrammar",
    "CustomFormatGrammarGrammarTypedDict",
    "CustomFormatGrammarTypedDict",
    "CustomFormatText",
    "CustomFormatTextTypedDict",
    "CustomOutput",
    "CustomOutputTypedDict",
    "DeleteCustomModelModelsCustomModelIDDeleteRequest",
    "DeleteCustomModelModelsCustomModelIDDeleteRequestTypedDict",
    "DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequest",
    "DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequestTypedDict",
    "DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequest",
    "DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequestTypedDict",
    "DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequest",
    "DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequestTypedDict",
    "DeleteFunctionFunctionsFunctionIDDeleteRequest",
    "DeleteFunctionFunctionsFunctionIDDeleteRequestTypedDict",
    "DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequest",
    "DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequestTypedDict",
    "DeleteKnowledgeBaseRequest",
    "DeleteKnowledgeBaseRequestTypedDict",
    "DeleteKnowledgeBaseResponse",
    "DeleteKnowledgeBaseResponseTypedDict",
    "DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequest",
    "DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequestTypedDict",
    "DeleteModelAliasModelsAliasesAliasIDDeleteRequest",
    "DeleteModelAliasModelsAliasesAliasIDDeleteRequestTypedDict",
    "DeleteSpanSpansSpanIDDeleteRequest",
    "DeleteSpanSpansSpanIDDeleteRequestTypedDict",
    "Delta",
    "DeltaTypedDict",
    "Detail",
    "Example",
    "ExampleIn",
    "ExampleInTypedDict",
    "ExampleTypedDict",
    "FeedbackInfo",
    "FeedbackInfoTypedDict",
    "File",
    "FileDownloadURLResponse",
    "FileDownloadURLResponseTypedDict",
    "FileFile",
    "FileFileTypedDict",
    "FileTypedDict",
    "Filter",
    "FilterTypedDict",
    "FinishReason",
    "Format",
    "FormatTypedDict",
    "FunctionCallConfigurationInput",
    "FunctionCallConfigurationInputTypedDict",
    "FunctionCallConfigurationOutput",
    "FunctionCallConfigurationOutputTypedDict",
    "FunctionCallInput",
    "FunctionCallInputTypedDict",
    "FunctionCallOutput",
    "FunctionCallOutputTypedDict",
    "FunctionDefinition",
    "FunctionDefinitionTypedDict",
    "FunctionOutput",
    "FunctionOutputTypedDict",
    "FunctionStreamCallStreamPostResponse",
    "FunctionStreamCallStreamPostResponseBody",
    "FunctionStreamCallStreamPostResponseBodyTypedDict",
    "FunctionStreamCallStreamPostResponseTypedDict",
    "GetCustomModelByNameModelsCustomByNameNameGetRequest",
    "GetCustomModelByNameModelsCustomByNameNameGetRequestTypedDict",
    "GetCustomModelModelsCustomModelIDGetRequest",
    "GetCustomModelModelsCustomModelIDGetRequestTypedDict",
    "GetCustomModelResponse",
    "GetCustomModelResponseTypedDict",
    "GetDatasetEntriesResponse",
    "GetDatasetEntriesResponseTypedDict",
    "GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequest",
    "GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequestTypedDict",
    "GetDatasetEntryResponse",
    "GetDatasetEntryResponseTypedDict",
    "GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequest",
    "GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequestTypedDict",
    "GetFunctionByNameFunctionsByNameNameGetRequest",
    "GetFunctionByNameFunctionsByNameNameGetRequestTypedDict",
    "GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequest",
    "GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequestTypedDict",
    "GetFunctionFunctionsFunctionIDGetRequest",
    "GetFunctionFunctionsFunctionIDGetRequestTypedDict",
    "GetFunctionResponse",
    "GetFunctionResponseTypedDict",
    "GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequest",
    "GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequestTypedDict",
    "GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequest",
    "GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequestTypedDict",
    "GetKnowledgeBaseResponse",
    "GetKnowledgeBaseResponseTypedDict",
    "GetMetricSpansSpanIDMetricsMetricIDGetRequest",
    "GetMetricSpansSpanIDMetricsMetricIDGetRequestTypedDict",
    "GetModelAliasByNameModelsAliasesByNameNameGetRequest",
    "GetModelAliasByNameModelsAliasesByNameNameGetRequestTypedDict",
    "GetModelAliasModelsAliasesAliasIDGetRequest",
    "GetModelAliasModelsAliasesAliasIDGetRequestTypedDict",
    "GetModelAliasResponse",
    "GetModelAliasResponseTypedDict",
    "GetSpanMetricResponse",
    "GetSpanMetricResponseTypedDict",
    "GetSpanResponse",
    "GetSpanResponseTypedDict",
    "GetSpanSpansSpanIDGetRequest",
    "GetSpanSpansSpanIDGetRequestTypedDict",
    "GetTraceResponse",
    "GetTraceResponseTypedDict",
    "GetTraceTracesTraceIDGetRequest",
    "GetTraceTracesTraceIDGetRequestTypedDict",
    "GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequest",
    "GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequestTypedDict",
    "GetUploadURLResponse",
    "GetUploadURLResponseTypedDict",
    "GetUsageResultItem",
    "GetUsageResultItemTypedDict",
    "Granularity",
    "ImageURL",
    "ImageURLTypedDict",
    "Input",
    "InputAudio",
    "InputAudioFormat",
    "InputAudioTypedDict",
    "InputTypedDict",
    "JSONPayload",
    "JSONPayloadTypedDict",
    "JSONSchema",
    "JSONSchemaTypedDict",
    "ListCustomModelsModelsCustomGetRequest",
    "ListCustomModelsModelsCustomGetRequestTypedDict",
    "ListCustomModelsResponseItem",
    "ListCustomModelsResponseItemTypedDict",
    "ListDatasetEntriesDatasetsDatasetIDEntriesGetRequest",
    "ListDatasetEntriesDatasetsDatasetIDEntriesGetRequestTypedDict",
    "ListFilesKnowledgeKnowledgeBaseIDFilesGetRequest",
    "ListFilesKnowledgeKnowledgeBaseIDFilesGetRequestTypedDict",
    "ListFilesResponse",
    "ListFilesResponseTypedDict",
    "ListFunctionRevisionResponse",
    "ListFunctionRevisionResponseTypedDict",
    "ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequest",
    "ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequestTypedDict",
    "ListFunctionsFunctionsGetRequest",
    "ListFunctionsFunctionsGetRequestTypedDict",
    "ListFunctionsResponseItem",
    "ListFunctionsResponseItemTypedDict",
    "ListKnowledgeBasesKnowledgeGetRequest",
    "ListKnowledgeBasesKnowledgeGetRequestTypedDict",
    "ListKnowledgeBasesResponse",
    "ListKnowledgeBasesResponseTypedDict",
    "ListLanguageModelsResponse",
    "ListLanguageModelsResponseTypedDict",
    "ListMetricsSpansSpanIDMetricsGetRequest",
    "ListMetricsSpansSpanIDMetricsGetRequestTypedDict",
    "ListModelAliasesModelsAliasesGetRequest",
    "ListModelAliasesModelsAliasesGetRequestTypedDict",
    "ListModelAliasesResponseItem",
    "ListModelAliasesResponseItemTypedDict",
    "ListModelsModelsGetRequest",
    "ListModelsModelsGetRequestTypedDict",
    "ListRerankModelsResponse",
    "ListRerankModelsResponseTypedDict",
    "ListSpanMetricsResponse",
    "ListSpanMetricsResponseTypedDict",
    "ListTracesResponse",
    "ListTracesResponseTypedDict",
    "ListTracesTracesGetRequest",
    "ListTracesTracesGetRequestTypedDict",
    "Meta",
    "MetaTypedDict",
    "Mode",
    "Model",
    "ModelTypedDict",
    "Op",
    "OpenaiTypesChatChatCompletionCustomToolParamCustom",
    "OpenaiTypesChatChatCompletionCustomToolParamCustomTypedDict",
    "OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustom",
    "OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustomTypedDict",
    "OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunction",
    "OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunctionTypedDict",
    "OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustom",
    "OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustomTypedDict",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunctionTypedDict",
    "OpenaiTypesChatCompletionCreateParamsFunction",
    "OpenaiTypesChatCompletionCreateParamsFunctionTypedDict",
    "PaginatedResponseGetDatasetEntriesResponse",
    "PaginatedResponseGetDatasetEntriesResponseTypedDict",
    "PaginatedResponseListCustomModelsResponseItem",
    "PaginatedResponseListCustomModelsResponseItemTypedDict",
    "PaginatedResponseListFilesResponse",
    "PaginatedResponseListFilesResponseTypedDict",
    "PaginatedResponseListFunctionRevisionResponse",
    "PaginatedResponseListFunctionRevisionResponseTypedDict",
    "PaginatedResponseListFunctionsResponseItem",
    "PaginatedResponseListFunctionsResponseItemTypedDict",
    "PaginatedResponseListKnowledgeBasesResponse",
    "PaginatedResponseListKnowledgeBasesResponseTypedDict",
    "PaginatedResponseListLanguageModelsResponse",
    "PaginatedResponseListLanguageModelsResponseTypedDict",
    "PaginatedResponseListModelAliasesResponseItem",
    "PaginatedResponseListModelAliasesResponseItemTypedDict",
    "PaginatedResponseListRerankModelsResponse",
    "PaginatedResponseListRerankModelsResponseTypedDict",
    "PaginatedResponseListSpanMetricsResponse",
    "PaginatedResponseListSpanMetricsResponseTypedDict",
    "PaginatedResponseListTracesResponse",
    "PaginatedResponseListTracesResponseTypedDict",
    "Payload",
    "PayloadTypedDict",
    "PromptTokensDetails",
    "PromptTokensDetailsTypedDict",
    "QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequest",
    "QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequestTypedDict",
    "QueryDatasetEntriesResponse",
    "QueryDatasetEntriesResponseTypedDict",
    "QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequest",
    "QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequestTypedDict",
    "QueryKnowledgeBaseRequest",
    "QueryKnowledgeBaseRequestTypedDict",
    "QueryKnowledgeBaseResponse",
    "QueryKnowledgeBaseResponseTypedDict",
    "RegisterCustomModelRequest",
    "RegisterCustomModelRequestTypedDict",
    "RegisterCustomModelResponse",
    "RegisterCustomModelResponseTypedDict",
    "RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequest",
    "RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequestTypedDict",
    "RegisterFileUploadRequest",
    "RegisterFileUploadRequestTypedDict",
    "RegisterFileUploadResponse",
    "RegisterFileUploadResponseTypedDict",
    "RerankCost",
    "RerankCostTypedDict",
    "RerankDocument",
    "RerankDocumentTypedDict",
    "RerankRequestModel",
    "RerankRequestModelTypedDict",
    "RerankResponseModel",
    "RerankResponseModelTypedDict",
    "RerankResult",
    "RerankResultTypedDict",
    "ResponseFormatJSONObject",
    "ResponseFormatJSONObjectTypedDict",
    "ResponseFormatJSONSchema",
    "ResponseFormatJSONSchemaTypedDict",
    "ResponseFormatText",
    "ResponseFormatTextTypedDict",
    "SaveToDatasetResponse",
    "SaveToDatasetResponseTypedDict",
    "SaveToDatasetSpansSpanIDSaveExamplesPostRequest",
    "SaveToDatasetSpansSpanIDSaveExamplesPostRequestTypedDict",
    "SearchContextSize",
    "Security",
    "SecurityTypedDict",
    "SpanData",
    "SpanDataTypedDict",
    "SpanMetricData",
    "SpanMetricDataTypedDict",
    "SpanSchema",
    "SpanSchemaTypedDict",
    "StreamFunctionFunctionsFunctionIDCallStreamPostData",
    "StreamFunctionFunctionsFunctionIDCallStreamPostDataTypedDict",
    "StreamFunctionFunctionsFunctionIDCallStreamPostRequest",
    "StreamFunctionFunctionsFunctionIDCallStreamPostRequestTypedDict",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponse",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseBody",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseBodyTypedDict",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseTypedDict",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostData",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostDataTypedDict",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequest",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequestTypedDict",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponse",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBody",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBodyTypedDict",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseTypedDict",
    "StreamingChunk",
    "StreamingChunkTypedDict",
    "SubmitFeedbackRequest",
    "SubmitFeedbackRequestTypedDict",
    "SubmitFeedbackResponse",
    "SubmitFeedbackResponseTypedDict",
    "SubmitSpanFeedbackSpansSpanIDFeedbackPostRequest",
    "SubmitSpanFeedbackSpansSpanIDFeedbackPostRequestTypedDict",
    "Syntax",
    "TModel",
    "TModel1",
    "TModel1TypedDict",
    "TModelTypedDict",
    "TextProcessingConfiguration",
    "TextProcessingConfigurationTypedDict",
    "TopLogprob",
    "TopLogprobTypedDict",
    "UpdateCustomModelModelsCustomModelIDPatchRequest",
    "UpdateCustomModelModelsCustomModelIDPatchRequestTypedDict",
    "UpdateCustomModelRequest",
    "UpdateCustomModelRequestTypedDict",
    "UpdateCustomModelResponse",
    "UpdateCustomModelResponseTypedDict",
    "UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequest",
    "UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequestTypedDict",
    "UpdateDatasetEntryRequest",
    "UpdateDatasetEntryRequestTypedDict",
    "UpdateDatasetEntryResponse",
    "UpdateDatasetEntryResponseTypedDict",
    "UpdateFunctionFunctionsFunctionIDPatchRequest",
    "UpdateFunctionFunctionsFunctionIDPatchRequestTypedDict",
    "UpdateFunctionRequest",
    "UpdateFunctionRequestTypedDict",
    "UpdateFunctionResponse",
    "UpdateFunctionResponseTypedDict",
    "UpdateMetricSpansSpanIDMetricsMetricIDPatchRequest",
    "UpdateMetricSpansSpanIDMetricsMetricIDPatchRequestTypedDict",
    "UpdateModelAliasModelsAliasesAliasIDPatchRequest",
    "UpdateModelAliasModelsAliasesAliasIDPatchRequestTypedDict",
    "UpdateModelAliasRequest",
    "UpdateModelAliasRequestTypedDict",
    "UpdateModelAliasResponse",
    "UpdateModelAliasResponseTypedDict",
    "UpdateSpanMetricRequest",
    "UpdateSpanMetricRequestTypedDict",
    "UpdateSpanMetricResponse",
    "UpdateSpanMetricResponseTypedDict",
    "UpdateSpanRequest",
    "UpdateSpanRequestTypedDict",
    "UpdateSpanResponse",
    "UpdateSpanResponseTypedDict",
    "UpdateSpanSpansSpanIDPatchRequest",
    "UpdateSpanSpansSpanIDPatchRequestTypedDict",
    "UploadFileKnowledgeKnowledgeBaseIDUploadPostRequest",
    "UploadFileKnowledgeKnowledgeBaseIDUploadPostRequestTypedDict",
    "UploadFileResponse",
    "UploadFileResponseTypedDict",
    "UsageAnalyticsUsageGetRequest",
    "UsageAnalyticsUsageGetRequestTypedDict",
    "Value1",
    "Value1TypedDict",
    "Value2",
    "Value2TypedDict",
    "Voice",
    "VoiceEnum",
    "VoiceTypedDict",
    "WebSearchOptions",
    "WebSearchOptionsTypedDict",
    "WebSearchOptionsUserLocation",
    "WebSearchOptionsUserLocationApproximate",
    "WebSearchOptionsUserLocationApproximateTypedDict",
    "WebSearchOptionsUserLocationTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AddKnowledgeKnowledgeBaseIDAddPostRequest": ".add_knowledge_knowledge_base_id_add_postop",
    "AddKnowledgeKnowledgeBaseIDAddPostRequestTypedDict": ".add_knowledge_knowledge_base_id_add_postop",
    "AddRequest": ".addrequest",
    "AddRequestTypedDict": ".addrequest",
    "Annotation": ".annotation",
    "AnnotationTypedDict": ".annotation",
    "AnnotationURLCitation": ".annotationurlcitation",
    "AnnotationURLCitationTypedDict": ".annotationurlcitation",
    "AppAPIPublicV2FunctionCallCallFunctionRequest": ".app_api_public_v2_function_call_callfunctionrequest",
    "AppAPIPublicV2FunctionCallCallFunctionRequestTypedDict": ".app_api_public_v2_function_call_callfunctionrequest",
    "AppAPIPublicV2FunctionCallCallFunctionResponse": ".app_api_public_v2_function_call_callfunctionresponse",
    "AppAPIPublicV2FunctionCallCallFunctionResponseTypedDict": ".app_api_public_v2_function_call_callfunctionresponse",
    "JSONPayload": ".app_api_public_v2_function_call_callfunctionresponse",
    "JSONPayloadTypedDict": ".app_api_public_v2_function_call_callfunctionresponse",
    "AppAPIPublicV2FunctionsCallFunctionRequest": ".app_api_public_v2_functions_callfunctionrequest",
    "AppAPIPublicV2FunctionsCallFunctionRequestTypedDict": ".app_api_public_v2_functions_callfunctionrequest",
    "AppAPIPublicV2FunctionsCallFunctionResponse": ".app_api_public_v2_functions_callfunctionresponse",
    "AppAPIPublicV2FunctionsCallFunctionResponseTypedDict": ".app_api_public_v2_functions_callfunctionresponse",
    "Audio": ".audio",
    "AudioTypedDict": ".audio",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPost": ".body_upload_file_knowledge_knowledge_base_id_upload_post",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFile": ".body_upload_file_knowledge_knowledge_base_id_upload_post",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostFileTypedDict": ".body_upload_file_knowledge_knowledge_base_id_upload_post",
    "BodyUploadFileKnowledgeKnowledgeBaseIDUploadPostTypedDict": ".body_upload_file_knowledge_knowledge_base_id_upload_post",
    "CallFunctionFunctionsFunctionIDCallPostRequest": ".call_function_functions_function_id_call_postop",
    "CallFunctionFunctionsFunctionIDCallPostRequestTypedDict": ".call_function_functions_function_id_call_postop",
    "CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequest": ".call_function_revision_functions_function_id_call_revision_id_postop",
    "CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequestTypedDict": ".call_function_revision_functions_function_id_call_revision_id_postop",
    "Payload": ".chat_completions_openai_chat_completions_postop",
    "PayloadTypedDict": ".chat_completions_openai_chat_completions_postop",
    "ChatCompletion": ".chatcompletion",
    "ChatCompletionServiceTier": ".chatcompletion",
    "ChatCompletionTypedDict": ".chatcompletion",
    "ChatCompletionAllowedToolChoiceParam": ".chatcompletionallowedtoolchoiceparam",
    "ChatCompletionAllowedToolChoiceParamTypedDict": ".chatcompletionallowedtoolchoiceparam",
    "ChatCompletionAllowedToolsParam": ".chatcompletionallowedtoolsparam",
    "ChatCompletionAllowedToolsParamTypedDict": ".chatcompletionallowedtoolsparam",
    "Mode": ".chatcompletionallowedtoolsparam",
    "ChatCompletionAssistantMessageParam": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamContent1": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamContent1TypedDict": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamContent2": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamContent2TypedDict": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamToolCall": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamToolCallTypedDict": ".chatcompletionassistantmessageparam",
    "ChatCompletionAssistantMessageParamTypedDict": ".chatcompletionassistantmessageparam",
    "ChatCompletionAudio": ".chatcompletionaudio",
    "ChatCompletionAudioTypedDict": ".chatcompletionaudio",
    "ChatCompletionAudioParam": ".chatcompletionaudioparam",
    "ChatCompletionAudioParamFormat": ".chatcompletionaudioparam",
    "ChatCompletionAudioParamTypedDict": ".chatcompletionaudioparam",
    "Voice": ".chatcompletionaudioparam",
    "VoiceEnum": ".chatcompletionaudioparam",
    "VoiceTypedDict": ".chatcompletionaudioparam",
    "ChatCompletionContentPartImageParam": ".chatcompletioncontentpartimageparam",
    "ChatCompletionContentPartImageParamTypedDict": ".chatcompletioncontentpartimageparam",
    "ChatCompletionContentPartInputAudioParam": ".chatcompletioncontentpartinputaudioparam",
    "ChatCompletionContentPartInputAudioParamTypedDict": ".chatcompletioncontentpartinputaudioparam",
    "ChatCompletionContentPartRefusalParam": ".chatcompletioncontentpartrefusalparam",
    "ChatCompletionContentPartRefusalParamTypedDict": ".chatcompletioncontentpartrefusalparam",
    "ChatCompletionContentPartTextParam": ".chatcompletioncontentparttextparam",
    "ChatCompletionContentPartTextParamTypedDict": ".chatcompletioncontentparttextparam",
    "ChatCompletionCustomToolParam": ".chatcompletioncustomtoolparam",
    "ChatCompletionCustomToolParamTypedDict": ".chatcompletioncustomtoolparam",
    "ChatCompletionDeveloperMessageParam": ".chatcompletiondevelopermessageparam",
    "ChatCompletionDeveloperMessageParamContent": ".chatcompletiondevelopermessageparam",
    "ChatCompletionDeveloperMessageParamContentTypedDict": ".chatcompletiondevelopermessageparam",
    "ChatCompletionDeveloperMessageParamTypedDict": ".chatcompletiondevelopermessageparam",
    "ChatCompletionFunctionCallOptionParam": ".chatcompletionfunctioncalloptionparam",
    "ChatCompletionFunctionCallOptionParamTypedDict": ".chatcompletionfunctioncalloptionparam",
    "ChatCompletionFunctionMessageParam": ".chatcompletionfunctionmessageparam",
    "ChatCompletionFunctionMessageParamTypedDict": ".chatcompletionfunctionmessageparam",
    "ChatCompletionFunctionToolParam": ".chatcompletionfunctiontoolparam",
    "ChatCompletionFunctionToolParamTypedDict": ".chatcompletionfunctiontoolparam",
    "ChatCompletionMessage": ".chatcompletionmessage",
    "ChatCompletionMessageToolCall": ".chatcompletionmessage",
    "ChatCompletionMessageToolCallTypedDict": ".chatcompletionmessage",
    "ChatCompletionMessageTypedDict": ".chatcompletionmessage",
    "ChatCompletionMessageCustomToolCall": ".chatcompletionmessagecustomtoolcall",
    "ChatCompletionMessageCustomToolCallTypedDict": ".chatcompletionmessagecustomtoolcall",
    "ChatCompletionMessageCustomToolCallParam": ".chatcompletionmessagecustomtoolcallparam",
    "ChatCompletionMessageCustomToolCallParamTypedDict": ".chatcompletionmessagecustomtoolcallparam",
    "ChatCompletionMessageFunctionToolCall": ".chatcompletionmessagefunctiontoolcall",
    "ChatCompletionMessageFunctionToolCallTypedDict": ".chatcompletionmessagefunctiontoolcall",
    "ChatCompletionMessageFunctionToolCallParam": ".chatcompletionmessagefunctiontoolcallparam",
    "ChatCompletionMessageFunctionToolCallParamTypedDict": ".chatcompletionmessagefunctiontoolcallparam",
    "ChatCompletionNamedToolChoiceCustomParam": ".chatcompletionnamedtoolchoicecustomparam",
    "ChatCompletionNamedToolChoiceCustomParamTypedDict": ".chatcompletionnamedtoolchoicecustomparam",
    "ChatCompletionNamedToolChoiceParam": ".chatcompletionnamedtoolchoiceparam",
    "ChatCompletionNamedToolChoiceParamTypedDict": ".chatcompletionnamedtoolchoiceparam",
    "ChatCompletionNonStreaming": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingFunctionCallEnum": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingFunctionCallUnion": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingFunctionCallUnionTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingMessage": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingMessageTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingModality": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingReasoningEffort": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingResponseFormat": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingResponseFormatTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingServiceTier": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingStop": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingStopTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingTool": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingToolChoiceEnum": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingToolChoiceUnion": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingToolChoiceUnionTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingToolTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingTypedDict": ".chatcompletionnonstreaming",
    "ChatCompletionNonStreamingVerbosity": ".chatcompletionnonstreaming",
    "ChatCompletionPredictionContentParam": ".chatcompletionpredictioncontentparam",
    "ChatCompletionPredictionContentParamContent": ".chatcompletionpredictioncontentparam",
    "ChatCompletionPredictionContentParamContentTypedDict": ".chatcompletionpredictioncontentparam",
    "ChatCompletionPredictionContentParamTypedDict": ".chatcompletionpredictioncontentparam",
    "ChatCompletionStreaming": ".chatcompletionstreaming",
    "ChatCompletionStreamingFunctionCallEnum": ".chatcompletionstreaming",
    "ChatCompletionStreamingFunctionCallUnion": ".chatcompletionstreaming",
    "ChatCompletionStreamingFunctionCallUnionTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingMessage": ".chatcompletionstreaming",
    "ChatCompletionStreamingMessageTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingModality": ".chatcompletionstreaming",
    "ChatCompletionStreamingReasoningEffort": ".chatcompletionstreaming",
    "ChatCompletionStreamingResponseFormat": ".chatcompletionstreaming",
    "ChatCompletionStreamingResponseFormatTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingServiceTier": ".chatcompletionstreaming",
    "ChatCompletionStreamingStop": ".chatcompletionstreaming",
    "ChatCompletionStreamingStopTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingTool": ".chatcompletionstreaming",
    "ChatCompletionStreamingToolChoiceEnum": ".chatcompletionstreaming",
    "ChatCompletionStreamingToolChoiceUnion": ".chatcompletionstreaming",
    "ChatCompletionStreamingToolChoiceUnionTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingToolTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingTypedDict": ".chatcompletionstreaming",
    "ChatCompletionStreamingVerbosity": ".chatcompletionstreaming",
    "ChatCompletionStreamOptionsParam": ".chatcompletionstreamoptionsparam",
    "ChatCompletionStreamOptionsParamTypedDict": ".chatcompletionstreamoptionsparam",
    "ChatCompletionSystemMessageParam": ".chatcompletionsystemmessageparam",
    "ChatCompletionSystemMessageParamContent": ".chatcompletionsystemmessageparam",
    "ChatCompletionSystemMessageParamContentTypedDict": ".chatcompletionsystemmessageparam",
    "ChatCompletionSystemMessageParamTypedDict": ".chatcompletionsystemmessageparam",
    "ChatCompletionTokenLogprob": ".chatcompletiontokenlogprob",
    "ChatCompletionTokenLogprobTypedDict": ".chatcompletiontokenlogprob",
    "ChatCompletionToolMessageParam": ".chatcompletiontoolmessageparam",
    "ChatCompletionToolMessageParamContent": ".chatcompletiontoolmessageparam",
    "ChatCompletionToolMessageParamContentTypedDict": ".chatcompletiontoolmessageparam",
    "ChatCompletionToolMessageParamTypedDict": ".chatcompletiontoolmessageparam",
    "ChatCompletionUserMessageParam": ".chatcompletionusermessageparam",
    "ChatCompletionUserMessageParamContent1": ".chatcompletionusermessageparam",
    "ChatCompletionUserMessageParamContent1TypedDict": ".chatcompletionusermessageparam",
    "ChatCompletionUserMessageParamContent2": ".chatcompletionusermessageparam",
    "ChatCompletionUserMessageParamContent2TypedDict": ".chatcompletionusermessageparam",
    "ChatCompletionUserMessageParamTypedDict": ".chatcompletionusermessageparam",
    "Choice": ".choice",
    "ChoiceTypedDict": ".choice",
    "FinishReason": ".choice",
    "ChoiceLogprobs": ".choicelogprobs",
    "ChoiceLogprobsTypedDict": ".choicelogprobs",
    "CompletionTokensDetails": ".completiontokensdetails",
    "CompletionTokensDetailsTypedDict": ".completiontokensdetails",
    "CompletionUsage": ".completionusage",
    "CompletionUsageTypedDict": ".completionusage",
    "CreateDatasetEntryDatasetsDatasetIDPostRequest": ".create_dataset_entry_datasets_dataset_id_postop",
    "CreateDatasetEntryDatasetsDatasetIDPostRequestTypedDict": ".create_dataset_entry_datasets_dataset_id_postop",
    "CreateMetricSpansSpanIDMetricsPostRequest": ".create_metric_spans_span_id_metrics_postop",
    "CreateMetricSpansSpanIDMetricsPostRequestTypedDict": ".create_metric_spans_span_id_metrics_postop",
    "CreateDatasetEntryRequest": ".createdatasetentryrequest",
    "CreateDatasetEntryRequestTypedDict": ".createdatasetentryrequest",
    "CreateDatasetEntryResponse": ".createdatasetentryresponse",
    "CreateDatasetEntryResponseTypedDict": ".createdatasetentryresponse",
    "CreateEmbeddingRequest": ".createembeddingrequest",
    "CreateEmbeddingRequestTypedDict": ".createembeddingrequest",
    "Input": ".createembeddingrequest",
    "InputTypedDict": ".createembeddingrequest",
    "CreateEmbeddingResponse": ".createembeddingresponse",
    "CreateEmbeddingResponseTypedDict": ".createembeddingresponse",
    "CreateFunctionRequest": ".createfunctionrequest",
    "CreateFunctionRequestTypedDict": ".createfunctionrequest",
    "CreateFunctionResponse": ".createfunctionresponse",
    "CreateFunctionResponseTypedDict": ".createfunctionresponse",
    "CreateKnowledgeBaseRequest": ".createknowledgebaserequest",
    "CreateKnowledgeBaseRequestTypedDict": ".createknowledgebaserequest",
    "CreateKnowledgeBaseResponse": ".createknowledgebaseresponse",
    "CreateKnowledgeBaseResponseTypedDict": ".createknowledgebaseresponse",
    "CreateModelAliasRequest": ".createmodelaliasrequest",
    "CreateModelAliasRequestTypedDict": ".createmodelaliasrequest",
    "CreateModelAliasResponse": ".createmodelaliasresponse",
    "CreateModelAliasResponseTypedDict": ".createmodelaliasresponse",
    "CreateSpanMetricRequest": ".createspanmetricrequest",
    "CreateSpanMetricRequestTypedDict": ".createspanmetricrequest",
    "CreateSpanMetricResponse": ".createspanmetricresponse",
    "CreateSpanMetricResponseTypedDict": ".createspanmetricresponse",
    "CreateSpanRequest": ".createspanrequest",
    "CreateSpanRequestTypedDict": ".createspanrequest",
    "CreateSpanResponse": ".createspanresponse",
    "CreateSpanResponseTypedDict": ".createspanresponse",
    "CustomOutput": ".custom_output",
    "CustomOutputTypedDict": ".custom_output",
    "CustomFormatGrammar": ".customformatgrammar",
    "CustomFormatGrammarTypedDict": ".customformatgrammar",
    "CustomFormatGrammarGrammar": ".customformatgrammargrammar",
    "CustomFormatGrammarGrammarTypedDict": ".customformatgrammargrammar",
    "Syntax": ".customformatgrammargrammar",
    "CustomFormatText": ".customformattext",
    "CustomFormatTextTypedDict": ".customformattext",
    "DeleteCustomModelModelsCustomModelIDDeleteRequest": ".delete_custom_model_models_custom_model_id_deleteop",
    "DeleteCustomModelModelsCustomModelIDDeleteRequestTypedDict": ".delete_custom_model_models_custom_model_id_deleteop",
    "DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequest": ".delete_dataset_entry_datasets_dataset_id_entries_entry_id_deleteop",
    "DeleteDatasetEntryDatasetsDatasetIDEntriesEntryIDDeleteRequestTypedDict": ".delete_dataset_entry_datasets_dataset_id_entries_entry_id_deleteop",
    "DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequest": ".delete_documents_knowledge_knowledge_base_id_query_deleteop",
    "DeleteDocumentsKnowledgeKnowledgeBaseIDQueryDeleteRequestTypedDict": ".delete_documents_knowledge_knowledge_base_id_query_deleteop",
    "DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequest": ".delete_file_from_knowledge_base_knowledge_knowledge_base_id_files_file_id_deleteop",
    "DeleteFileFromKnowledgeBaseKnowledgeKnowledgeBaseIDFilesFileIDDeleteRequestTypedDict": ".delete_file_from_knowledge_base_knowledge_knowledge_base_id_files_file_id_deleteop",
    "DeleteFunctionFunctionsFunctionIDDeleteRequest": ".delete_function_functions_function_id_deleteop",
    "DeleteFunctionFunctionsFunctionIDDeleteRequestTypedDict": ".delete_function_functions_function_id_deleteop",
    "DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequest": ".delete_knowledge_base_knowledge_knowledge_base_id_deleteop",
    "DeleteKnowledgeBaseKnowledgeKnowledgeBaseIDDeleteRequestTypedDict": ".delete_knowledge_base_knowledge_knowledge_base_id_deleteop",
    "DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequest": ".delete_metric_spans_span_id_metrics_metric_id_deleteop",
    "DeleteMetricSpansSpanIDMetricsMetricIDDeleteRequestTypedDict": ".delete_metric_spans_span_id_metrics_metric_id_deleteop",
    "DeleteModelAliasModelsAliasesAliasIDDeleteRequest": ".delete_model_alias_models_aliases_alias_id_deleteop",
    "DeleteModelAliasModelsAliasesAliasIDDeleteRequestTypedDict": ".delete_model_alias_models_aliases_alias_id_deleteop",
    "DeleteSpanSpansSpanIDDeleteRequest": ".delete_span_spans_span_id_deleteop",
    "DeleteSpanSpansSpanIDDeleteRequestTypedDict": ".delete_span_spans_span_id_deleteop",
    "DeleteKnowledgeBaseRequest": ".deleteknowledgebaserequest",
    "DeleteKnowledgeBaseRequestTypedDict": ".deleteknowledgebaserequest",
    "DeleteKnowledgeBaseResponse": ".deleteknowledgebaseresponse",
    "DeleteKnowledgeBaseResponseTypedDict": ".deleteknowledgebaseresponse",
    "Example": ".example",
    "ExampleTypedDict": ".example",
    "ExampleIn": ".examplein",
    "ExampleInTypedDict": ".examplein",
    "FeedbackInfo": ".feedbackinfo",
    "FeedbackInfoTypedDict": ".feedbackinfo",
    "File": ".file",
    "FileTypedDict": ".file",
    "FileDownloadURLResponse": ".filedownloadurlresponse",
    "FileDownloadURLResponseTypedDict": ".filedownloadurlresponse",
    "FileFile": ".filefile",
    "FileFileTypedDict": ".filefile",
    "Filter": ".filter_",
    "FilterTypedDict": ".filter_",
    "Value1": ".filter_",
    "Value1TypedDict": ".filter_",
    "Value2": ".filter_",
    "Value2TypedDict": ".filter_",
    "FunctionOutput": ".function_output",
    "FunctionOutputTypedDict": ".function_output",
    "Delta": ".function_stream_call_stream_postop",
    "DeltaTypedDict": ".function_stream_call_stream_postop",
    "FunctionStreamCallStreamPostResponse": ".function_stream_call_stream_postop",
    "FunctionStreamCallStreamPostResponseBody": ".function_stream_call_stream_postop",
    "FunctionStreamCallStreamPostResponseBodyTypedDict": ".function_stream_call_stream_postop",
    "FunctionStreamCallStreamPostResponseTypedDict": ".function_stream_call_stream_postop",
    "StreamingChunk": ".function_stream_call_stream_postop",
    "StreamingChunkTypedDict": ".function_stream_call_stream_postop",
    "FunctionCallInput": ".functioncall_input",
    "FunctionCallInputTypedDict": ".functioncall_input",
    "FunctionCallOutput": ".functioncall_output",
    "FunctionCallOutputTypedDict": ".functioncall_output",
    "FunctionCallConfigurationInput": ".functioncallconfiguration_input",
    "FunctionCallConfigurationInputTypedDict": ".functioncallconfiguration_input",
    "FunctionCallConfigurationOutput": ".functioncallconfiguration_output",
    "FunctionCallConfigurationOutputTypedDict": ".functioncallconfiguration_output",
    "FunctionDefinition": ".functiondefinition",
    "FunctionDefinitionTypedDict": ".functiondefinition",
    "GetCustomModelByNameModelsCustomByNameNameGetRequest": ".get_custom_model_by_name_models_custom_by_name_name_getop",
    "GetCustomModelByNameModelsCustomByNameNameGetRequestTypedDict": ".get_custom_model_by_name_models_custom_by_name_name_getop",
    "GetCustomModelModelsCustomModelIDGetRequest": ".get_custom_model_models_custom_model_id_getop",
    "GetCustomModelModelsCustomModelIDGetRequestTypedDict": ".get_custom_model_models_custom_model_id_getop",
    "GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequest": ".get_dataset_entry_datasets_dataset_id_entries_entry_id_getop",
    "GetDatasetEntryDatasetsDatasetIDEntriesEntryIDGetRequestTypedDict": ".get_dataset_entry_datasets_dataset_id_entries_entry_id_getop",
    "GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequest": ".get_file_download_url_knowledge_knowledge_base_id_files_file_id_download_url_getop",
    "GetFileDownloadURLKnowledgeKnowledgeBaseIDFilesFileIDDownloadURLGetRequestTypedDict": ".get_file_download_url_knowledge_knowledge_base_id_files_file_id_download_url_getop",
    "GetFunctionByNameFunctionsByNameNameGetRequest": ".get_function_by_name_functions_by_name_name_getop",
    "GetFunctionByNameFunctionsByNameNameGetRequestTypedDict": ".get_function_by_name_functions_by_name_name_getop",
    "GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequest": ".get_function_by_revision_functions_function_id_revisions_revision_id_getop",
    "GetFunctionByRevisionFunctionsFunctionIDRevisionsRevisionIDGetRequestTypedDict": ".get_function_by_revision_functions_function_id_revisions_revision_id_getop",
    "GetFunctionFunctionsFunctionIDGetRequest": ".get_function_functions_function_id_getop",
    "GetFunctionFunctionsFunctionIDGetRequestTypedDict": ".get_function_functions_function_id_getop",
    "GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequest": ".get_knowledge_base_by_name_knowledge_by_name_knowledge_base_name_getop",
    "GetKnowledgeBaseByNameKnowledgeByNameKnowledgeBaseNameGetRequestTypedDict": ".get_knowledge_base_by_name_knowledge_by_name_knowledge_base_name_getop",
    "GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequest": ".get_knowledge_base_knowledge_knowledge_base_id_getop",
    "GetKnowledgeBaseKnowledgeKnowledgeBaseIDGetRequestTypedDict": ".get_knowledge_base_knowledge_knowledge_base_id_getop",
    "GetMetricSpansSpanIDMetricsMetricIDGetRequest": ".get_metric_spans_span_id_metrics_metric_id_getop",
    "GetMetricSpansSpanIDMetricsMetricIDGetRequestTypedDict": ".get_metric_spans_span_id_metrics_metric_id_getop",
    "GetModelAliasByNameModelsAliasesByNameNameGetRequest": ".get_model_alias_by_name_models_aliases_by_name_name_getop",
    "GetModelAliasByNameModelsAliasesByNameNameGetRequestTypedDict": ".get_model_alias_by_name_models_aliases_by_name_name_getop",
    "GetModelAliasModelsAliasesAliasIDGetRequest": ".get_model_alias_models_aliases_alias_id_getop",
    "GetModelAliasModelsAliasesAliasIDGetRequestTypedDict": ".get_model_alias_models_aliases_alias_id_getop",
    "GetSpanSpansSpanIDGetRequest": ".get_span_spans_span_id_getop",
    "GetSpanSpansSpanIDGetRequestTypedDict": ".get_span_spans_span_id_getop",
    "GetTraceTracesTraceIDGetRequest": ".get_trace_traces_trace_id_getop",
    "GetTraceTracesTraceIDGetRequestTypedDict": ".get_trace_traces_trace_id_getop",
    "GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequest": ".get_upload_url_knowledge_knowledge_base_id_upload_url_getop",
    "GetUploadURLKnowledgeKnowledgeBaseIDUploadURLGetRequestTypedDict": ".get_upload_url_knowledge_knowledge_base_id_upload_url_getop",
    "GetCustomModelResponse": ".getcustommodelresponse",
    "GetCustomModelResponseTypedDict": ".getcustommodelresponse",
    "GetDatasetEntriesResponse": ".getdatasetentriesresponse",
    "GetDatasetEntriesResponseTypedDict": ".getdatasetentriesresponse",
    "GetDatasetEntryResponse": ".getdatasetentryresponse",
    "GetDatasetEntryResponseTypedDict": ".getdatasetentryresponse",
    "GetFunctionResponse": ".getfunctionresponse",
    "GetFunctionResponseTypedDict": ".getfunctionresponse",
    "GetKnowledgeBaseResponse": ".getknowledgebaseresponse",
    "GetKnowledgeBaseResponseTypedDict": ".getknowledgebaseresponse",
    "GetModelAliasResponse": ".getmodelaliasresponse",
    "GetModelAliasResponseTypedDict": ".getmodelaliasresponse",
    "GetSpanMetricResponse": ".getspanmetricresponse",
    "GetSpanMetricResponseTypedDict": ".getspanmetricresponse",
    "GetSpanResponse": ".getspanresponse",
    "GetSpanResponseTypedDict": ".getspanresponse",
    "GetTraceResponse": ".gettraceresponse",
    "GetTraceResponseTypedDict": ".gettraceresponse",
    "GetUploadURLResponse": ".getuploadurlresponse",
    "GetUploadURLResponseTypedDict": ".getuploadurlresponse",
    "GetUsageResultItem": ".getusageresultitem",
    "GetUsageResultItemTypedDict": ".getusageresultitem",
    "Granularity": ".granularity",
    "Detail": ".imageurl",
    "ImageURL": ".imageurl",
    "ImageURLTypedDict": ".imageurl",
    "InputAudio": ".inputaudio",
    "InputAudioFormat": ".inputaudio",
    "InputAudioTypedDict": ".inputaudio",
    "JSONSchema": ".jsonschema",
    "JSONSchemaTypedDict": ".jsonschema",
    "ListCustomModelsModelsCustomGetRequest": ".list_custom_models_models_custom_getop",
    "ListCustomModelsModelsCustomGetRequestTypedDict": ".list_custom_models_models_custom_getop",
    "ListDatasetEntriesDatasetsDatasetIDEntriesGetRequest": ".list_dataset_entries_datasets_dataset_id_entries_getop",
    "ListDatasetEntriesDatasetsDatasetIDEntriesGetRequestTypedDict": ".list_dataset_entries_datasets_dataset_id_entries_getop",
    "ListFilesKnowledgeKnowledgeBaseIDFilesGetRequest": ".list_files_knowledge_knowledge_base_id_files_getop",
    "ListFilesKnowledgeKnowledgeBaseIDFilesGetRequestTypedDict": ".list_files_knowledge_knowledge_base_id_files_getop",
    "ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequest": ".list_function_revisions_functions_function_id_revisions_getop",
    "ListFunctionRevisionsFunctionsFunctionIDRevisionsGetRequestTypedDict": ".list_function_revisions_functions_function_id_revisions_getop",
    "ListFunctionsFunctionsGetRequest": ".list_functions_functions_getop",
    "ListFunctionsFunctionsGetRequestTypedDict": ".list_functions_functions_getop",
    "ListKnowledgeBasesKnowledgeGetRequest": ".list_knowledge_bases_knowledge_getop",
    "ListKnowledgeBasesKnowledgeGetRequestTypedDict": ".list_knowledge_bases_knowledge_getop",
    "ListMetricsSpansSpanIDMetricsGetRequest": ".list_metrics_spans_span_id_metrics_getop",
    "ListMetricsSpansSpanIDMetricsGetRequestTypedDict": ".list_metrics_spans_span_id_metrics_getop",
    "ListModelAliasesModelsAliasesGetRequest": ".list_model_aliases_models_aliases_getop",
    "ListModelAliasesModelsAliasesGetRequestTypedDict": ".list_model_aliases_models_aliases_getop",
    "ListModelsModelsGetRequest": ".list_models_models_getop",
    "ListModelsModelsGetRequestTypedDict": ".list_models_models_getop",
    "ListTracesTracesGetRequest": ".list_traces_traces_getop",
    "ListTracesTracesGetRequestTypedDict": ".list_traces_traces_getop",
    "ListCustomModelsResponseItem": ".listcustommodelsresponseitem",
    "ListCustomModelsResponseItemTypedDict": ".listcustommodelsresponseitem",
    "ListFilesResponse": ".listfilesresponse",
    "ListFilesResponseTypedDict": ".listfilesresponse",
    "ListFunctionRevisionResponse": ".listfunctionrevisionresponse",
    "ListFunctionRevisionResponseTypedDict": ".listfunctionrevisionresponse",
    "ListFunctionsResponseItem": ".listfunctionsresponseitem",
    "ListFunctionsResponseItemTypedDict": ".listfunctionsresponseitem",
    "ListKnowledgeBasesResponse": ".listknowledgebasesresponse",
    "ListKnowledgeBasesResponseTypedDict": ".listknowledgebasesresponse",
    "ListLanguageModelsResponse": ".listlanguagemodelsresponse",
    "ListLanguageModelsResponseTypedDict": ".listlanguagemodelsresponse",
    "ListModelAliasesResponseItem": ".listmodelaliasesresponseitem",
    "ListModelAliasesResponseItemTypedDict": ".listmodelaliasesresponseitem",
    "ListRerankModelsResponse": ".listrerankmodelsresponse",
    "ListRerankModelsResponseTypedDict": ".listrerankmodelsresponse",
    "ListSpanMetricsResponse": ".listspanmetricsresponse",
    "ListSpanMetricsResponseTypedDict": ".listspanmetricsresponse",
    "ListTracesResponse": ".listtracesresponse",
    "ListTracesResponseTypedDict": ".listtracesresponse",
    "Meta": ".meta",
    "MetaTypedDict": ".meta",
    "Model": ".model",
    "ModelTypedDict": ".model",
    "Op": ".op",
    "Format": ".openai_types_chat_chat_completion_custom_tool_param_custom",
    "FormatTypedDict": ".openai_types_chat_chat_completion_custom_tool_param_custom",
    "OpenaiTypesChatChatCompletionCustomToolParamCustom": ".openai_types_chat_chat_completion_custom_tool_param_custom",
    "OpenaiTypesChatChatCompletionCustomToolParamCustomTypedDict": ".openai_types_chat_chat_completion_custom_tool_param_custom",
    "OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustom": ".openai_types_chat_chat_completion_message_custom_tool_call_param_custom",
    "OpenaiTypesChatChatCompletionMessageCustomToolCallParamCustomTypedDict": ".openai_types_chat_chat_completion_message_custom_tool_call_param_custom",
    "OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunction": ".openai_types_chat_chat_completion_message_function_tool_call_param_function",
    "OpenaiTypesChatChatCompletionMessageFunctionToolCallParamFunctionTypedDict": ".openai_types_chat_chat_completion_message_function_tool_call_param_function",
    "OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustom": ".openai_types_chat_chat_completion_named_tool_choice_custom_param_custom",
    "OpenaiTypesChatChatCompletionNamedToolChoiceCustomParamCustomTypedDict": ".openai_types_chat_chat_completion_named_tool_choice_custom_param_custom",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction": ".openai_types_chat_chat_completion_named_tool_choice_param_function",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunctionTypedDict": ".openai_types_chat_chat_completion_named_tool_choice_param_function",
    "OpenaiTypesChatCompletionCreateParamsFunction": ".openai_types_chat_completion_create_params_function",
    "OpenaiTypesChatCompletionCreateParamsFunctionTypedDict": ".openai_types_chat_completion_create_params_function",
    "PaginatedResponseGetDatasetEntriesResponse": ".paginatedresponse_getdatasetentriesresponse_",
    "PaginatedResponseGetDatasetEntriesResponseTypedDict": ".paginatedresponse_getdatasetentriesresponse_",
    "PaginatedResponseListCustomModelsResponseItem": ".paginatedresponse_listcustommodelsresponseitem_",
    "PaginatedResponseListCustomModelsResponseItemTypedDict": ".paginatedresponse_listcustommodelsresponseitem_",
    "PaginatedResponseListFilesResponse": ".paginatedresponse_listfilesresponse_",
    "PaginatedResponseListFilesResponseTypedDict": ".paginatedresponse_listfilesresponse_",
    "PaginatedResponseListFunctionRevisionResponse": ".paginatedresponse_listfunctionrevisionresponse_",
    "PaginatedResponseListFunctionRevisionResponseTypedDict": ".paginatedresponse_listfunctionrevisionresponse_",
    "PaginatedResponseListFunctionsResponseItem": ".paginatedresponse_listfunctionsresponseitem_",
    "PaginatedResponseListFunctionsResponseItemTypedDict": ".paginatedresponse_listfunctionsresponseitem_",
    "PaginatedResponseListKnowledgeBasesResponse": ".paginatedresponse_listknowledgebasesresponse_",
    "PaginatedResponseListKnowledgeBasesResponseTypedDict": ".paginatedresponse_listknowledgebasesresponse_",
    "PaginatedResponseListLanguageModelsResponse": ".paginatedresponse_listlanguagemodelsresponse_",
    "PaginatedResponseListLanguageModelsResponseTypedDict": ".paginatedresponse_listlanguagemodelsresponse_",
    "PaginatedResponseListModelAliasesResponseItem": ".paginatedresponse_listmodelaliasesresponseitem_",
    "PaginatedResponseListModelAliasesResponseItemTypedDict": ".paginatedresponse_listmodelaliasesresponseitem_",
    "PaginatedResponseListRerankModelsResponse": ".paginatedresponse_listrerankmodelsresponse_",
    "PaginatedResponseListRerankModelsResponseTypedDict": ".paginatedresponse_listrerankmodelsresponse_",
    "PaginatedResponseListSpanMetricsResponse": ".paginatedresponse_listspanmetricsresponse_",
    "PaginatedResponseListSpanMetricsResponseTypedDict": ".paginatedresponse_listspanmetricsresponse_",
    "PaginatedResponseListTracesResponse": ".paginatedresponse_listtracesresponse_",
    "PaginatedResponseListTracesResponseTypedDict": ".paginatedresponse_listtracesresponse_",
    "PromptTokensDetails": ".prompttokensdetails",
    "PromptTokensDetailsTypedDict": ".prompttokensdetails",
    "QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequest": ".query_dataset_entries_datasets_dataset_id_entries_query_postop",
    "QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequestTypedDict": ".query_dataset_entries_datasets_dataset_id_entries_query_postop",
    "QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequest": ".query_knowledge_base_knowledge_knowledge_base_id_query_postop",
    "QueryKnowledgeBaseKnowledgeKnowledgeBaseIDQueryPostRequestTypedDict": ".query_knowledge_base_knowledge_knowledge_base_id_query_postop",
    "QueryDatasetEntriesResponse": ".querydatasetentriesresponse",
    "QueryDatasetEntriesResponseTypedDict": ".querydatasetentriesresponse",
    "QueryKnowledgeBaseRequest": ".queryknowledgebaserequest",
    "QueryKnowledgeBaseRequestTypedDict": ".queryknowledgebaserequest",
    "QueryKnowledgeBaseResponse": ".queryknowledgebaseresponse",
    "QueryKnowledgeBaseResponseTypedDict": ".queryknowledgebaseresponse",
    "RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequest": ".register_file_upload_knowledge_knowledge_base_id_register_file_postop",
    "RegisterFileUploadKnowledgeKnowledgeBaseIDRegisterFilePostRequestTypedDict": ".register_file_upload_knowledge_knowledge_base_id_register_file_postop",
    "RegisterCustomModelRequest": ".registercustommodelrequest",
    "RegisterCustomModelRequestTypedDict": ".registercustommodelrequest",
    "RegisterCustomModelResponse": ".registercustommodelresponse",
    "RegisterCustomModelResponseTypedDict": ".registercustommodelresponse",
    "RegisterFileUploadRequest": ".registerfileuploadrequest",
    "RegisterFileUploadRequestTypedDict": ".registerfileuploadrequest",
    "RegisterFileUploadResponse": ".registerfileuploadresponse",
    "RegisterFileUploadResponseTypedDict": ".registerfileuploadresponse",
    "RerankCost": ".rerankcost",
    "RerankCostTypedDict": ".rerankcost",
    "RerankDocument": ".rerankdocument",
    "RerankDocumentTypedDict": ".rerankdocument",
    "RerankRequestModel": ".rerankrequestmodel",
    "RerankRequestModelTypedDict": ".rerankrequestmodel",
    "RerankResponseModel": ".rerankresponsemodel",
    "RerankResponseModelTypedDict": ".rerankresponsemodel",
    "RerankResult": ".rerankresult",
    "RerankResultTypedDict": ".rerankresult",
    "ResponseFormatJSONObject": ".responseformatjsonobject",
    "ResponseFormatJSONObjectTypedDict": ".responseformatjsonobject",
    "ResponseFormatJSONSchema": ".responseformatjsonschema",
    "ResponseFormatJSONSchemaTypedDict": ".responseformatjsonschema",
    "ResponseFormatText": ".responseformattext",
    "ResponseFormatTextTypedDict": ".responseformattext",
    "SaveToDatasetSpansSpanIDSaveExamplesPostRequest": ".save_to_dataset_spans_span_id_save_examples_postop",
    "SaveToDatasetSpansSpanIDSaveExamplesPostRequestTypedDict": ".save_to_dataset_spans_span_id_save_examples_postop",
    "SaveToDatasetResponse": ".savetodatasetresponse",
    "SaveToDatasetResponseTypedDict": ".savetodatasetresponse",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SpanData": ".spandata",
    "SpanDataTypedDict": ".spandata",
    "SpanMetricData": ".spanmetricdata",
    "SpanMetricDataTypedDict": ".spanmetricdata",
    "SpanSchema": ".spanschema",
    "SpanSchemaTypedDict": ".spanschema",
    "StreamFunctionFunctionsFunctionIDCallStreamPostData": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostDataTypedDict": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostRequest": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostRequestTypedDict": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponse": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseBody": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseBodyTypedDict": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionFunctionsFunctionIDCallStreamPostResponseTypedDict": ".stream_function_functions_function_id_call_stream_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostData": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostDataTypedDict": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequest": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostRequestTypedDict": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponse": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBody": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseBodyTypedDict": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "StreamFunctionRevisionFunctionsFunctionIDCallStreamRevisionIDPostResponseTypedDict": ".stream_function_revision_functions_function_id_call_stream_revision_id_postop",
    "SubmitSpanFeedbackSpansSpanIDFeedbackPostRequest": ".submit_span_feedback_spans_span_id_feedback_postop",
    "SubmitSpanFeedbackSpansSpanIDFeedbackPostRequestTypedDict": ".submit_span_feedback_spans_span_id_feedback_postop",
    "SubmitFeedbackRequest": ".submitfeedbackrequest",
    "SubmitFeedbackRequestTypedDict": ".submitfeedbackrequest",
    "SubmitFeedbackResponse": ".submitfeedbackresponse",
    "SubmitFeedbackResponseTypedDict": ".submitfeedbackresponse",
    "TextProcessingConfiguration": ".textprocessingconfiguration",
    "TextProcessingConfigurationTypedDict": ".textprocessingconfiguration",
    "TModel": ".tmodel",
    "TModel1": ".tmodel",
    "TModel1TypedDict": ".tmodel",
    "TModelTypedDict": ".tmodel",
    "TopLogprob": ".toplogprob",
    "TopLogprobTypedDict": ".toplogprob",
    "UpdateCustomModelModelsCustomModelIDPatchRequest": ".update_custom_model_models_custom_model_id_patchop",
    "UpdateCustomModelModelsCustomModelIDPatchRequestTypedDict": ".update_custom_model_models_custom_model_id_patchop",
    "UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequest": ".update_dataset_entry_datasets_dataset_id_entries_entry_id_patchop",
    "UpdateDatasetEntryDatasetsDatasetIDEntriesEntryIDPatchRequestTypedDict": ".update_dataset_entry_datasets_dataset_id_entries_entry_id_patchop",
    "UpdateFunctionFunctionsFunctionIDPatchRequest": ".update_function_functions_function_id_patchop",
    "UpdateFunctionFunctionsFunctionIDPatchRequestTypedDict": ".update_function_functions_function_id_patchop",
    "UpdateMetricSpansSpanIDMetricsMetricIDPatchRequest": ".update_metric_spans_span_id_metrics_metric_id_patchop",
    "UpdateMetricSpansSpanIDMetricsMetricIDPatchRequestTypedDict": ".update_metric_spans_span_id_metrics_metric_id_patchop",
    "UpdateModelAliasModelsAliasesAliasIDPatchRequest": ".update_model_alias_models_aliases_alias_id_patchop",
    "UpdateModelAliasModelsAliasesAliasIDPatchRequestTypedDict": ".update_model_alias_models_aliases_alias_id_patchop",
    "UpdateSpanSpansSpanIDPatchRequest": ".update_span_spans_span_id_patchop",
    "UpdateSpanSpansSpanIDPatchRequestTypedDict": ".update_span_spans_span_id_patchop",
    "UpdateCustomModelRequest": ".updatecustommodelrequest",
    "UpdateCustomModelRequestTypedDict": ".updatecustommodelrequest",
    "UpdateCustomModelResponse": ".updatecustommodelresponse",
    "UpdateCustomModelResponseTypedDict": ".updatecustommodelresponse",
    "UpdateDatasetEntryRequest": ".updatedatasetentryrequest",
    "UpdateDatasetEntryRequestTypedDict": ".updatedatasetentryrequest",
    "UpdateDatasetEntryResponse": ".updatedatasetentryresponse",
    "UpdateDatasetEntryResponseTypedDict": ".updatedatasetentryresponse",
    "UpdateFunctionRequest": ".updatefunctionrequest",
    "UpdateFunctionRequestTypedDict": ".updatefunctionrequest",
    "UpdateFunctionResponse": ".updatefunctionresponse",
    "UpdateFunctionResponseTypedDict": ".updatefunctionresponse",
    "UpdateModelAliasRequest": ".updatemodelaliasrequest",
    "UpdateModelAliasRequestTypedDict": ".updatemodelaliasrequest",
    "UpdateModelAliasResponse": ".updatemodelaliasresponse",
    "UpdateModelAliasResponseTypedDict": ".updatemodelaliasresponse",
    "UpdateSpanMetricRequest": ".updatespanmetricrequest",
    "UpdateSpanMetricRequestTypedDict": ".updatespanmetricrequest",
    "UpdateSpanMetricResponse": ".updatespanmetricresponse",
    "UpdateSpanMetricResponseTypedDict": ".updatespanmetricresponse",
    "UpdateSpanRequest": ".updatespanrequest",
    "UpdateSpanRequestTypedDict": ".updatespanrequest",
    "UpdateSpanResponse": ".updatespanresponse",
    "UpdateSpanResponseTypedDict": ".updatespanresponse",
    "UploadFileKnowledgeKnowledgeBaseIDUploadPostRequest": ".upload_file_knowledge_knowledge_base_id_upload_postop",
    "UploadFileKnowledgeKnowledgeBaseIDUploadPostRequestTypedDict": ".upload_file_knowledge_knowledge_base_id_upload_postop",
    "UploadFileResponse": ".uploadfileresponse",
    "UploadFileResponseTypedDict": ".uploadfileresponse",
    "UsageAnalyticsUsageGetRequest": ".usage_analytics_usage_getop",
    "UsageAnalyticsUsageGetRequestTypedDict": ".usage_analytics_usage_getop",
    "SearchContextSize": ".websearchoptions",
    "WebSearchOptions": ".websearchoptions",
    "WebSearchOptionsTypedDict": ".websearchoptions",
    "WebSearchOptionsUserLocation": ".websearchoptionsuserlocation",
    "WebSearchOptionsUserLocationTypedDict": ".websearchoptionsuserlocation",
    "WebSearchOptionsUserLocationApproximate": ".websearchoptionsuserlocationapproximate",
    "WebSearchOptionsUserLocationApproximateTypedDict": ".websearchoptionsuserlocationapproximate",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
